
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#include "colordefs.h"
#include "FrameMain.h"
#include "CanvasMain.h"
#include "CanvasRun.h"
#include "lattice.h"
#include "latticefunc.h"
#include "data.h"
#include "macros.h"

extern data dq;

CanvasMain::CanvasMain(wxWindow *parent, int x, int y, int width, int height):
  GLCanvas(parent, x, y, width, height)
{
  /* Set scrollbars to:
   *   20 pixels per horizontal units (1 unit = 1 scroll line)
   *   20 pixels per vertical units
   *   50 horizontal units
   *   50 vertical units
   *   10 units per horizontal page
   *   10 units per vertical page.
   * Virtual canvas is therefore 1000 pixels by 1000 pixels.
   */
  //SetScrollbars(20, 20, 50, 50, 10, 10);

  this_parent = (FrameMain*)parent;

//glClearColor(BLUE);
  glClearColor(BLACK);
//glClearColor(WHITE);
//glClearColor(LIGHTGRAY1);
//glClearColor(LIGHTGRAY2);
//glClearColor(LIGHTGRAY3);
  glClear(GL_COLOR_BUFFER_BIT);

//glShadeModel(GL_FLAT);
//glMatrixMode(GL_PROJECTION);

  glEnable(GL_BLEND);
  glBlendFunc(GL_SRC_ALPHA,GL_ONE);

  glOrtho(0.,dq.ortho_x,0.,dq.ortho_y,-dq.ortho_z,dq.ortho_z);

  for (int i=0; i<3; i++)
    pp[i] = new lattice(16,16);

/* =======================>>>>>>>>>>>>>>>>>>>>>>========================= */
// drawCanvasMain = NULL;
// drawCanvasMain = new wxBitmap(dq.size_canvas_x,dq.size_canvas_y);
// dc2.SelectObject(drawCanvasMain);
/* =======================<<<<<<<<<<<<<<<<<<<<<<========================= */
// dc2.Clear();
/*
  for (int jj=0; jj<100; jj++)
   for (int ii=0; ii<25; ii++)
     dc2.DrawPoint(ii,jj);
*/
}

CanvasMain::~CanvasMain(void)
{
  for (int i=0; i<3; i++)
    delete [] pp[i];
}

// Called when canvas is resized.
void CanvasMain::OnSize(int w, int h)
{
//  wxCanvas::OnSize(w, h);
}

// Called when canvas needs to be repainted.
void CanvasMain::OnPaint(void)
{ 
  PRINT1("OnPaint::CanvasMain");
  this_parent->canvasRun->ClearCanvas();

//GLSetCurrent();
 
  Draw();

  // SWITCH OFF THE REDRAWING
  dq.switch_redraw_canvasrun = 0;

  PRINT1("done CanvasMain::OnPaint");
}

/*
// Called when canvas needs to be repainted.
void CanvasMain::OnPaint(void)
{ 
PRINT1("OnPaint::CanvasMain");

//GLSetCurrent();
 
//wxDC *dc = GetDC();

//if ( dq.switch_redraw_canvasrun )
     Draw();
//else
//   dc_orig->Blit(0,0, dq.size_canvas_x, dq.size_canvas_y, &dc2, 0, 0, wxCOPY);

  wxCanvasDC *dc3;
//dc3 = this_parent->canvasRun->GetDC();

  if ( dq.switch_redraw_canvasrun )
  {
//   this_parent->canvasRun->OnPaint();
//   dc2.Blit(0,0, dq.size_canvas_x, dq.size_canvas_y, dc3, 0, 0, wxCOPY);
  }

//dc2.Blit(0,0, dq.size_canvas_x, dq.size_canvas_y, GetDC(), 0, 0, wxCOPY);
//dc3->Blit(0,0, dq.size_canvas_x, dq.size_canvas_y, &dc2, 0, 0, wxCOPY);
//dc2.Blit(0,0, dq.size_canvas_x, dq.size_canvas_y, dc3, 0, 0, wxCOPY);
//dc->Blit(0,0, dq.size_canvas_x, dq.size_canvas_y, &dc2, 0, 0, wxCOPY);
//dc->Blit(0,0, dq.size_canvas_x, dq.size_canvas_y, 
//	&(this_parent->canvasRun->dc2), 0, 0, wxCOPY);


  // SWITCH OFF THE REDRAWING
  dq.switch_redraw_canvasrun = 0;

//wx_dc = dc_orig;
PRINT1("done CanvasMain::OnPaint");
}
*/

void CanvasMain::Draw(void)
{
  PRINT1("CanvasMain::Draw");

  glClear(GL_COLOR_BUFFER_BIT);

  for (int i=0; i<3; i++)
  {
     PRINT4("   * slice ",i," switch ",dq.switchReadSlice[i]);
     PRINT2("     display list",dq.displayList[i]);

     if (dq.switchReadSlice[i]) 
       for (int j=0; j<dq.sweep_ch[i]; j++)
          glCallList(dq.displayList[i]);
/*
     if (dq.switchReadSlice[i]) glCallList(dq.displayList[i]);
     // NOT PAINT THE PLAQUE TWICE
     if (i!=1) 
         if (dq.switchReadSlice[i]) 
             glCallList(dq.displayList[i]);
     // PAINT THIRD CHANNEL THREE TIMES
     if (i==2) 
         if (dq.switchReadSlice[i]) 
             glCallList(dq.displayList[i]);
*/
     glFlush();
  }

  // BEGIN TRACES

  PRINT1("done drawing...!");

//glFlush();

//GLSwapBuffers();
}

void CanvasMain::ClearCanvas(void)
{
  PRINT1("ClearCanvas::CanvasMain");
  GLSetCurrent();
  glClearColor(BLACK);
//glClearColor(WHITE);
//glClearColor(LIGHTGRAY1);
//glClearColor(LIGHTGRAY2);
//glClearColor(LIGHTGRAY3);
  glFlush();
}

// Called when the canvas receives a mouse event.
void CanvasMain::OnEvent(wxMouseEvent& event)
{
  float x,y;
  event.Position(&x, &y);

//wxCanvas::OnEvent(event);
}

// Called when the canvas receives a key event.
void CanvasMain::OnChar(wxKeyEvent& event)
{
PRINT1("on CanvasMain::OnChar");
  char buf[2];
  buf[0] = (char)event.KeyCode();
  buf[1] = 0;

  cout << "key event " << event.KeyCode() << "\n" << flush;
  switch ( event.KeyCode() )
  {
	case WXK_UP:
	{
	  break;
	}
	case WXK_DOWN:
	{
	  break;
	}
	case WXK_RIGHT:
	{
	  break;
	}
	case WXK_LEFT:
	{
	  break;
	}
  }

  // Process the default behaviour
  wxCanvas::OnChar(event);
}

void CanvasMain::DoDisplayList(int num)
{
     PRINT1("!&! in CanvasMain::DoDisplayList ");
     int dim_lat_x = (pp[num])->m;
     int dim_lat_y = (pp[num])->n;

     GLuint list = glGenLists(1);


     if (list != 0)
     {
        // STORE THE DISPLAY LIST NUMBER
        dq.displayList[num] = list;

        PRINT4("---> disp list ",list," for lattice ",num);

        switch(num)
        {
           case 0:
           {
	      glNewList(list, GL_COMPILE);
		 glBegin(GL_POINTS);
		    for (int i=0; i<dim_lat_x; i++)
		       for (int j=0; j<dim_lat_y; j++)
		       {
			 float col = (*(pp[num]))(i,j);
//			 glColor4f(col,0.,0.,.3333333);
  			 glColor4f(ramp_func(col,dq),0.,0.,.3333333);
//			 glColor4f(0.,0.,ramp_func(col,dq),.3333333);
			 glVertex3i(i, j, num);
		       }
		 glEnd();   
	      glEndList();

	      // MARK LATTICE AS READ
	      dq.switchReadSlice[num] = 1;
              break;
           }
           case 1:
           {
	      glNewList(list, GL_COMPILE);
		 glBegin(GL_POINTS);
		    for (int i=0; i<dim_lat_x; i++)
		       for (int j=0; j<dim_lat_y; j++)
		       {
			 float col = (*(pp[num]))(i,j);
  			 glColor4f(0.,ramp_func(col,dq),0.,.3333333);
//			 glColor4f(0.,0.,ramp_func(col,dq),.3333333);
			 glVertex3i(i, j, num);
		       }
		 glEnd();   
	      glEndList();

	      // MARK LATTICE AS READ
	      dq.switchReadSlice[num] = 1;
              break;
           }
           case 2:
           {
	      glNewList(list, GL_COMPILE);
		 glBegin(GL_POINTS);
		    for (int i=0; i<dim_lat_x; i++)
		       for (int j=0; j<dim_lat_y; j++)
		       {
			 float col = (*(pp[num]))(i,j);
			 glColor4f(0.,0.,ramp_func(col,dq),.3333333);
			 glVertex3i(i, j, num);
		       }
		 glEnd();   
	      glEndList();

	      // MARK LATTICE AS READ
	      dq.switchReadSlice[num] = 1;
              break;
           }
        }
     }
     else
     {
	PRINT1("NO DISPLAY LIST INDICES AVAILABLE!");      
     }
PRINT1("!&! out CanvasMain::DoDisplayList ");
}

void CanvasMain::DeleteDisplayLists(void)
{
     for (int i=0; i<3; i++)
     {
        if (dq.displayList[i]!=-1)
          glDeleteLists(dq.displayList[i],1);
     }
}

void CanvasMain::DeleteDisplayList(int no)
{
     if (dq.displayList[no]!=-1)
     {
       glDeleteLists(dq.displayList[no],1);
       dq.displayList[no]     = -1;
       dq.switchReadSlice[no] = 0;
     }
}

/*
======================================================================
*/
