
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#include <math.h>
#include <time.h>
#include "wx_utils.h"
#include "colordefs.h"
#include "FrameMain.h"
#include "CanvasRun.h"
#include "CanvasMain.h"
#include "data.h"
#include "macros.h"
#include "Text.h"
#include "curvature.h"
#include "lattice.h"
#include "latticefunc.h"

extern data dq;

CanvasRun::CanvasRun(wxWindow *parent, int x, int y, int width, int height):
  GLCanvas(parent, x, y, width, height)
{
  /* Set scrollbars to:
   *   20 pixels per horizontal units (1 unit = 1 scroll line)
   *   20 pixels per vertical units
   *   50 horizontal units
   *   50 vertical units
   *   10 units per horizontal page
   *   10 units per vertical page.
   * Virtual canvas is therefore 1000 pixels by 1000 pixels.
   */
  //SetScrollbars(20, 20, 50, 50, 10, 10);
  canvasRun_parent = (FrameMain*)parent;

//glClearColor(BLUE);
  glClearColor(BLACK);
//glClearColor(WHITE);
//glClearColor(LIGHTGRAY1);
//glClearColor(LIGHTGRAY2);
//glClearColor(LIGHTGRAY3);
  glClear(GL_COLOR_BUFFER_BIT);

//glShadeModel(GL_FLAT);
//glMatrixMode(GL_PROJECTION);

  glEnable(GL_BLEND);
  glBlendFunc(GL_SRC_ALPHA,GL_ONE);

  glOrtho(0.,dq.ortho_x,0.,dq.ortho_y,-dq.ortho_z,dq.ortho_z);
}

CanvasRun::~CanvasRun(void)
{
}

// Called when canvas is resized.
void CanvasRun::OnSize(int w, int h)
{
//  wxCanvas::OnSize(w, h);
}

// Called when canvas needs to be repainted.
void CanvasRun::OnPaint(void)
{
   PRINT1("OnPaint::CanvasRun");
}

void CanvasRun::ClearCanvas(void)
{
  PRINT1("ClearCanvas::CanvasRun");
  GLSetCurrent();
  glClearColor(BLACK);
//glClearColor(WHITE);
//glClearColor(LIGHTGRAY1);
//glClearColor(LIGHTGRAY2);
//glClearColor(LIGHTGRAY3);
  glFlush();
}

// Called when the canvas receives a mouse event.
void CanvasRun::OnEvent(wxMouseEvent& event)
{
  float x,y;
  float x_real,y_real;
  char buf_curv1[200];
  char buf_curv2[200];
  char buf_total_s[200];
  char buf_dist_r0_rn[200];
  char buf_RG[200];
  char buf_width[200];
  event.Position(&x, &y);
  wxDC *dc_mouse = GetDC();

  if ( dq.switch_mode_curv_width == 1) 
  {

    /* *
     * CURVATURE MODE, TRACES NEURITES LENGHWISE
     * AND CALCULATES CURVATURE, RADIUS OF GYRATION, ETC
     * */

    if ( event.MiddleDown() )
    {
      /* *
       * BEGIN TRACING OF LINES AND CALCULATION OF CURVATURES
       * */
      if (dq.switch_init_data_collect)
      {
	// GET PICTURE COORDINATES
	x_real = ( x / dq.size_canvas_x ) * dq.ortho_x;
	y_real = ( (dq.size_canvas_y-y) / dq.size_canvas_y ) * dq.ortho_y;

	// GET NEW POINTS
	dq.x1_p    = x_real; dq.y1_p    = y_real;
	dq.x1_canv = x;      dq.y1_canv = y;

	// INITIALIZE IF FIRST POINT
	if (dq.switch_first_point_data_collect)
	{
	   // CLEAN LISTS OF POINTS
	   // CLEAN TOTAL LENGTH ACCUMULATED
	   dq.ClearLists();
	   dq.total_s = 0.;
	   dq.accum_pos_x    = 0.;
	   dq.accum_pos_y    = 0.;
	   dq.accum_pos_xsqr = 0.;
	   dq.accum_pos_ysqr = 0.;

	   // INITIALIZE FIRST POINT
	   dq.x0_p = x_real; dq.y0_p = y_real;
	   dq.x0_canv = x;   dq.y0_canv = y;

	   dq.switch_first_point_data_collect = 0;

  /**/     // HEADER FOR NEW COLLECTION
	   time_t a = time(NULL);
	   *(canvasRun_parent->frameText->textMain) << "#\n# START NEW -- CURVATURE CALCULATIONS\n"
		     << "#\t" << ctime(&a);
	   *(canvasRun_parent->frameText->textMain) << "#\n"
		     << "# (1) LENGTH (2) X_p (3) Y_p (4) CURVATURE (5) ABS[CURV] (6) R ORIGIN (7) RG \n";
			   
	}
	// DRAW CONTINUING LINE ON CANVAS
	dc_mouse->SetPen(wxWHITE_PEN);
	dc_mouse->DrawLine(dq.x0_canv, dq.y0_canv, dq.x1_canv, dq.y1_canv);

	// DISPLACEMENT
	float disp_sx = dq.x1_p - dq.x0_p;
	float disp_sy = dq.y1_p - dq.y0_p;
	float disp_sr = sqrt( disp_sx*disp_sx + disp_sy*disp_sy );
	dq.total_s   += disp_sr;

	// STORE NEW POINTS AND TOTAL DISTANCE IN LISTS
	dq.list_x.add_one(dq.x1_p); dq.list_y.add_one(dq.y1_p);
	dq.accum_s.add_one( dq.total_s );

	// STORE RADIAL DISTANCE FROM ORIGIN
	float disp_x0_xn = dq.list_x[dq.list_x.last_one] - dq.list_x[0];
	float disp_y0_yn = dq.list_y[dq.list_y.last_one] - dq.list_y[0];
	float disp_r0_rn = sqrt( disp_x0_xn*disp_x0_xn + disp_y0_yn*disp_y0_yn );
	dq.dist_r0_rn.add_one( disp_r0_rn );

	// STORE STATISTICS, RADIUS OF GYRATION
	dq.accum_pos_x    += disp_sr * ( dq.x1_p + dq.x0_p ) / 2.;
	dq.accum_pos_xsqr += disp_sr * CUAD( (dq.x1_p + dq.x0_p)/2. );
	dq.accum_pos_y    += disp_sr * ( dq.y1_p + dq.y0_p ) / 2.;
	dq.accum_pos_ysqr += disp_sr * CUAD( (dq.y1_p + dq.y0_p)/2. );
	float dum_RG_1;
	float dum_RG_2;
	float dum_RG;
        if ( dq.total_s != 0. )	
        {
	   dum_RG_1 = ( dq.accum_pos_xsqr + dq.accum_pos_ysqr ) / dq.total_s;
	   dum_RG_2 = ( CUAD(dq.accum_pos_x) + CUAD(dq.accum_pos_y) ) / CUAD( dq.total_s );
	   dum_RG   = sqrt( ABS(dum_RG_1 - dum_RG_2) );
        }
        else dum_RG = -1.;
	dq.RG.add_one( dum_RG );

	// WRITE TO TEXT BOX
	sprintf(buf_total_s, "%e", dq.total_s);
  /**/  *(canvasRun_parent->frameText->textMain) << buf_total_s << " ";
  /**/  *(canvasRun_parent->frameText->textMain) << dq.x1_p << " " << dq.y1_p << " ";

	// UPDATE POSITIONS
	dq.x0_p    = dq.x1_p;    dq.y0_p    = dq.y1_p;
	dq.x0_canv = dq.x1_canv; dq.y0_canv = dq.y1_canv;

	// CALCULATE CURVATURE
	float curv1,curv2;
	curv1 = threept_curv_mth1(dq);
	PRINT2("-* CURVATURE  ",curv1);
	// WRITE CURVATURES TO LISTS
	dq.curv_3pt_1.add_one(curv1);   

	// WRITE CURVATURES TO TEXT BOX
	// REAL CURVATURE
	sprintf(buf_curv1, "%e", curv1);
  /**/  *(canvasRun_parent->frameText->textMain) << buf_curv1 << "  ";
	// ABSOLUTE OF CURVATURE
	sprintf(buf_curv1, "%e", ABS(curv1));
  /**/  *(canvasRun_parent->frameText->textMain) << buf_curv1 << "  ";

	// WRITE TOTAL DISPLACEMENT FROM ORIGIN
	sprintf(buf_dist_r0_rn, "%e", disp_r0_rn);
  /**/  *(canvasRun_parent->frameText->textMain) << buf_dist_r0_rn << "  ";
	// WRITE RG AS FUNCTION OF LENGTH
	sprintf(buf_RG, "%e", dum_RG);
  /**/  *(canvasRun_parent->frameText->textMain) << buf_RG << "  ";

	// CARRIAGE RETURN IN TEXT BOX
  /**/  *(canvasRun_parent->frameText->textMain) << "\n";
      }
      /* *
       * FINISH TRACING OF LINES AND CALCULATION OF CURVATURES
       * */
    }
    else if ( event.LeftDown() )
    {
	  cout << "mouse position " << x << " " << y << "\n" << flush;
	  cout << "real coordinates " << (x/dq.size_canvas_x)*dq.ortho_x << " "
				      << ((dq.size_canvas_y-y)/dq.size_canvas_y)*dq.ortho_y << " "
				      << "\n" << flush;
  //      cout << "pixel value " << (*pp)(int((x/dq.size_canvas_x)*dq.ortho_x),int(((dq.size_canvas_y-y)/dq.size_canvas_y)*dq.ortho_y)) << "\n" << flush;
    }
    else if ( event.RightDown() )
    {
       float x0, y0, x1, y1;

       dc_mouse->SetPen(wxWHITE_PEN);
       float list_x_all_0 = dq.list_x_all[0];
       float list_y_all_0 = dq.list_y_all[0];
       x0 = list_x_all_0 * dq.size_canvas_x / dq.ortho_x;
       y0 = dq.size_canvas_y - (list_y_all_0 * dq.size_canvas_y) / dq.ortho_y;
       for (int i=1; i<=dq.list_x_all.last_one; i++)
       {
	   float list_x_all_i = dq.list_x_all[i];
	   float list_y_all_i = dq.list_y_all[i];
	   x1 = list_x_all_i * dq.size_canvas_x / dq.ortho_x;
	   y1 = dq.size_canvas_y - (list_y_all_i * dq.size_canvas_y) / dq.ortho_y;
	   dc_mouse->DrawLine(x0, y0, x1, y1);
	   PRINT4(x0,y0,x1,y1);
	   x0 = x1;
	   y0 = y1;
       }  
    }
  }   
  else if ( dq.switch_mode_curv_width == 2) 
  {

    /* *
     * WIDTH MODE, MEASURES WIDTHS BASED ON TWO-POINT CLICKS
     * */

    if ( event.MiddleDown() )
    {
      /* *
       * BEGIN TRACING OF LINES AND CALCULATION OF WIDTHS
       * */
      if (dq.switch_init_data_collect)
      {
	// GET PICTURE COORDINATES
	x_real = ( x / dq.size_canvas_x ) * dq.ortho_x;
	y_real = ( (dq.size_canvas_y-y) / dq.size_canvas_y ) * dq.ortho_y;

	// GET NEW POINTS
	dq.x1_w    = x_real; dq.y1_w    = y_real;
	dq.x1_canv = x;      dq.y1_canv = y;

	// INITIALIZE IF FIRST POINT
	if (dq.switch_first_point_data_collect)
	{
	   // CLEAN LISTS OF POINTS
	   // CLEAN TOTAL LENGTH ACCUMULATED
	   dq.ClearLists();
	   dq.total_s = 0.;

	   // INITIALIZE FIRST POINT
	   dq.x0_w = x_real; dq.y0_w = y_real;
	   dq.x0_canv = x;   dq.y0_canv = y;
           dq.switch_is_first_width_point = 1;
           dq.switch_is_second_width_done = 0;

           // DONT COME TO THIS LOOP ANYMORE
	   dq.switch_first_point_data_collect = 0;

/**/       // HEADER FOR NEW COLLECTION
	   time_t a = time(NULL);
	   *(canvasRun_parent->frameText->textSecon) << "#\n# START NEW -- WIDTH CALCULATION\n"
		     << "#\t" << ctime(&a);
	   *(canvasRun_parent->frameText->textSecon) << "#\n"
		     << "# (1) DISPLACEMENT (2) WIDTH (3) X_w (4) Y_w \n";
	}

        // FIRST POINT IN THE WIDTH
        if ( dq.switch_is_first_width_point )
        {
            // NO LONGER THE FIRST POINT IN THIS PARTICULAR WIDTH
            dq.switch_is_first_width_point = 0;
        }
        // SECOND POINT IN THE WIDTH
        else if ( !dq.switch_is_first_width_point )
        {
	    // DRAW CONTINUING LINE ON CANVAS
	    dc_mouse->SetPen(wxWHITE_PEN);
	    dc_mouse->DrawLine(dq.x0_canv, dq.y0_canv, dq.x1_canv, dq.y1_canv);

	    // CALCULATE MID POINT
	    dq.x1_mid_w  = ( dq.x1_w + dq.x0_w ) / 2.;
	    dq.y1_mid_w  = ( dq.y1_w + dq.y0_w ) / 2.;

            // INITIALIZE THE FIRST MID POINT
            if ( !dq.switch_is_second_width_done )
            {
               // CALCULATE MID POINT
               dq.x0_mid_w  = ( dq.x1_w + dq.x0_w ) / 2.;
               dq.y0_mid_w  = ( dq.y1_w + dq.y0_w ) / 2.;
 
               // DONT COME BACK TO THIS LOOP
               dq.switch_is_second_width_done = 1;
            }

	    // DISPLACEMENT
	    float disp_sx = dq.x1_mid_w - dq.x0_mid_w;
	    float disp_sy = dq.y1_mid_w - dq.y0_mid_w;
	    float disp_sr = sqrt( disp_sx*disp_sx + disp_sy*disp_sy );
	    dq.total_s   += disp_sr;
	    dq.accum_s_w.add_one( dq.total_s );

            // WIDTH
            float x_width = dq.x1_w - dq.x0_w;
            float y_width = dq.y1_w - dq.y0_w;
            float s_width = sqrt( x_width*x_width + y_width*y_width );

	    // WRITE TO TEXT BOX
	    sprintf(buf_total_s, "%e", dq.total_s);
/**/        *(canvasRun_parent->frameText->textSecon) << buf_total_s << " ";
	    sprintf(buf_width, "%e", s_width);
/**/        *(canvasRun_parent->frameText->textSecon) << buf_width << " ";
/**/        *(canvasRun_parent->frameText->textSecon) << dq.x1_w << " " << dq.y1_w << " ";

	    // CARRIAGE RETURN IN TEXT BOX
/**/        *(canvasRun_parent->frameText->textSecon) << "\n";

            // STORE OLD FOR NEXT LOOP
	    dq.x0_mid_w  = dq.x1_mid_w;
	    dq.y0_mid_w  = dq.y1_mid_w;

            // NEXT ONE IS THE FIRST POINT IN THIS PARTICULAR WIDTH
            dq.switch_is_first_width_point = 1;
        }

	// STORE NEW POINTS 
	dq.list_x_w.add_one(dq.x1_w); dq.list_y_w.add_one(dq.y1_w);

	// UPDATE POSITIONS
	dq.x0_w    = dq.x1_w;    dq.y0_w    = dq.y1_w;
	dq.x0_canv = dq.x1_canv; dq.y0_canv = dq.y1_canv;
      }
      /* *
       * FINISH WIDTH CALCULATION
       * */
    }
    else if ( event.LeftDown() )
    {
	  cout << "mouse position " << x << " " << y << "\n" << flush;
	  cout << "real coordinates " << (x/dq.size_canvas_x)*dq.ortho_x << " "
				      << ((dq.size_canvas_y-y)/dq.size_canvas_y)*dq.ortho_y << " "
				      << "\n" << flush;
  //      cout << "pixel value " << (*pp)(int((x/dq.size_canvas_x)*dq.ortho_x),int(((dq.size_canvas_y-y)/dq.size_canvas_y)*dq.ortho_y)) << "\n" << flush;
    }
    else if ( event.RightDown() )
    {
       float x0, y0, x1, y1;

       dc_mouse->SetPen(wxWHITE_PEN);
       float list_x_all_0 = dq.list_x_w_all[0];
       float list_y_all_0 = dq.list_y_w_all[0];
       x0 = list_x_all_0 * dq.size_canvas_x / dq.ortho_x;
       y0 = dq.size_canvas_y - (list_y_all_0 * dq.size_canvas_y) / dq.ortho_y;
       for (int i=1; i<=dq.list_x_w_all.last_one; i++)
       {
	   float list_x_all_i = dq.list_x_w_all[i];
	   float list_y_all_i = dq.list_y_w_all[i];
	   x1 = list_x_all_i * dq.size_canvas_x / dq.ortho_x;
	   y1 = dq.size_canvas_y - (list_y_all_i * dq.size_canvas_y) / dq.ortho_y;
	   dc_mouse->DrawLine(x0, y0, x1, y1);
	   PRINT4(x0,y0,x1,y1);
	   x0 = x1;
	   y0 = y1;
       }  
    }
  }
  else if ( dq.switch_mode_curv_width == 3) 
  {

    /* *
     * PIXEL VALUE MODE, PRINTS VALUE OF PIXEL TO CONSOLE
     * */

    if ( event.MiddleDown() )
    {
        int i,j,k;

	// GET PICTURE COORDINATES
	x_real = ( x / dq.size_canvas_x ) * dq.ortho_x;
	y_real = ( (dq.size_canvas_y-y) / dq.size_canvas_y ) * dq.ortho_y;
 
        PRINT5("COOR: (",x_real,", ",y_real,")");

        // PRINT SLICE, PIXEL VALUE, AND MAPPED PIXEL VALUE
        int ind_x = int(x_real);
        int ind_y = int(y_real);
        for (i=0; i<3; i++)
        {
           if ( (canvasRun_parent->canvasMain->pp[i]!=NULL) 
             && ((*(canvasRun_parent->canvasMain->pp[i]))(ind_x,ind_y)>=0.)
             && ((*(canvasRun_parent->canvasMain->pp[i]))(ind_x,ind_y)<=1.)
              )
           {
              PRINT6 ( "\tSLICE: ", i, " VALUE: " , 
                       (*(canvasRun_parent->canvasMain->pp[i]))(ind_x,ind_y), 
                       " MAPPED VALUE: " , 
                       ramp_func( (*(canvasRun_parent->canvasMain->pp[i]))(ind_x,ind_y),dq )
                     );
           }
        }
    }
  }
  else 
  {
     PRINT1("NO MODE SELECTION...!");
  }
//wxCanvas::OnEvent(event);
}

// Called when the canvas receives a key event.
void CanvasRun::OnChar(wxKeyEvent& event)
{
  PRINT1("on CanvasRun::OnChar");

  char buf[2];
  buf[0] = (char)event.KeyCode();
  buf[1] = 0;

  cout << "key event " << event.KeyCode() << "\n" << flush;
  switch ( event.KeyCode() )
  {
	case WXK_UP:
	{
	  break;
	}
	case WXK_DOWN:
	{
	  break;
	}
	case WXK_RIGHT:
	{
	  break;
	}
	case WXK_LEFT:
	{
	  break;
	}
  }

  // Process the default behaviour
  wxCanvas::OnChar(event);
}

/*
======================================================================
*/
