
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#include "wx_menu.h"
#include "wx_utils.h"
#include "wb_cmdlg.h"
#include "FrameMenu.h"
#include "FrameMain.h"
#include "CanvasMain.h"
#include "CanvasRun.h"
#include "App.h"
#include "lattice.h"
#include "latticefunc.h"
#include "picfunc.h"
#include "data.h"
#include "macros.h"
#include "Text.h"
#include "Folders.h"

extern AppClass theApp;
extern data dq;

FrameMenu::FrameMenu(wxFrame *parent, char *title, int x, int y, int width, int height, long style, char *name):
  wxFrame(parent, title, x, y, width, height, style, name)
{
  frameMain = NULL;

  menuBar = new wxMenuBar;

  wxMenu *menuFile = new wxMenu;
  menuFile->Append(FRAMEMENU_READ_RED, "&Read Red");
  menuFile->Append(FRAMEMENU_READ_GREEN, "&Read Green");
  menuFile->Append(FRAMEMENU_READ_BLUE, "&Read Blue");
  menuFile->AppendSeparator();
  menuFile->Append(FRAMEMENU_OPEN, "&Open");
  menuFile->Append(FRAMEMENU_OPEN3, "O&pen 3 Slices");
  menuFile->AppendSeparator();
  menuFile->Append(FRAMEMENU_KILLCHANNEL, "&Kill Channel");
  menuFile->Append(FRAMEMENU_MODIFYCHANNEL, "&Modify Channel");
//menuFile->Append(FRAMEMENU_CLOSE, "&Close");
  menuFile->AppendSeparator();
//menuFile->Append(FRAMEMENU_SHOW, "&Show");
//menuFile->Append(FRAMEMENU_HIDE, "&Hide");
  menuFile->Append(FRAMEMENU_REFRESH, "&Refresh");
  menuFile->Append(FRAMEMENU_CLEAR, "C&lear");
  menuFile->AppendSeparator();
  menuFile->Append(FRAMEMENU_QUIT, "&Quit");
  menuBar->Append(menuFile, "&File");

  wxMenu *menuInits = new wxMenu;
//menuInits->Append(FRAMEMENU_PUTINIT0, "Init 0");
//menuBar->Append(menuInits, "&Inits");

  wxMenu *menuData = new wxMenu;
//menuData->Append(FRAMEMENU_TEXTBOX, "Text Box");
//menuData->AppendSeparator();
  menuData->Append(FRAMEMENU_INITCOLLECT, "Start...","Checkable Item",TRUE);
  menuData->Append(FRAMEMENU_FINITCOLLECT, "Finish.","Checkable Item",TRUE);
  menuData->Check(FRAMEMENU_INITCOLLECT, FALSE);
  menuData->Check(FRAMEMENU_FINITCOLLECT, FALSE);
  menuData->AppendSeparator();
  menuData->Append(FRAMEMENU_CANCELCOLLECT, "Cancel Trace");
  menuBar->Append(menuData, "&Data");

  wxMenu *menuMode = new wxMenu;
  menuMode->Append(FRAMEMENU_MODECURV, "Curvatures","Checkable Item",TRUE);
  menuMode->Append(FRAMEMENU_MODEWIDTH, "Widths","Checkable Item",TRUE);
  menuMode->Append(FRAMEMENU_MODEVALUE, "Pix Value","Checkable Item",TRUE);
  menuMode->AppendSeparator();
  menuMode->Append(FRAMEMENU_SETUP, "Setup");
  menuMode->Check(FRAMEMENU_MODECURV, TRUE);
  menuMode->Check(FRAMEMENU_MODEWIDTH, FALSE);
  menuMode->Check(FRAMEMENU_MODEVALUE, FALSE);
  menuBar->Append(menuMode, "&Mode");

  SetMenuBar(menuBar);

  // Status Bar
  CreateStatusLine();

  // Ensure the subwindows get resized o.k.
  OnSize(width, height);

  // Centre frame on the screen.
//Centre(wxBOTH);

  // Show the frame.
  Show(TRUE);

  SetStatusText("Simulation in progress...");

  frameMain = new FrameMain(NULL, "Main", 669, 450, dq.size_canvas_x, dq.size_canvas_y, wxSDI | wxDEFAULT_FRAME, "");

  cursor_arrow = new wxCursor(wxCURSOR_ARROW);
//cursor_cross = new wxCursor(wxCURSOR_CROSS);
  cursor_cross = new wxCursor(wxCURSOR_PENCIL);
  cursor_value = new wxCursor(wxCURSOR_CROSS);
}

FrameMenu::~FrameMenu(void)
{
}

Bool FrameMenu::OnClose(void)
{
  // Clean up any associated data here.
  return TRUE;
}

void FrameMenu::OnSize(int w, int h)
{
  // Let default member handle sizing for only one subwindow.
  wxFrame::OnSize(w, h);
}

void FrameMenu::OnMenuCommand(int commandId)
{
  switch (commandId)
  {
    case FRAMEMENU_READ_RED:
    {
      int reduction, slice_no;
      int start_x, start_y;
      long dum_x, dum_y, no_slices;
      char b_dum[77];

      char* s_1_dum = wxFileSelector("Picture File", NULL, NULL, NULL, "*.PIC");

      if (s_1_dum)
      {
	  cout << "File read " << s_1_dum << "\n" << flush;
	  SetStatusText(s_1_dum);

	  ifstream file_i(s_1_dum);
	  file_i.read(b_dum,76);

	  no_slices = slices_PIC(b_dum, dum_x, dum_y);    

	  char* dum5 = wxGetTextFromUser("Slice?", "Total Slices", LongToString(no_slices), this);

          if (dum5)
          {
	      StringToInt(dum5, &slice_no);

	      // THIS READS A SLICE OF THE PICTURE.
	      (frameMain->canvasMain->pp[0])->resize(1024,1024);
	      read_reduced_PIC_slice(file_i, dum_x, dum_y, slice_no, *(frameMain->canvasMain->pp[0]) );

	      // SO THAT THE CANVAS REDRAWS
	      dq.switch_redraw_canvasrun = 1;

	      // RE-DO DISPLAY LISTS AND PAINT
	      frameMain->canvasMain->DoDisplayList(0);
	      frameMain->canvasMain->OnPaint();

	      file_i.close();

	      cout << "done...!\n" << flush;
          }
      }

      break;
    }
    case FRAMEMENU_READ_GREEN:
    {
      int reduction, slice_no;
      int start_x, start_y;
      long dum_x, dum_y, no_slices;
      char b_dum[77];

      char* s_1_dum = wxFileSelector("Picture File", NULL, NULL, NULL, "*.PIC");

      if (s_1_dum)
      {
	  cout << "File read " << s_1_dum << "\n" << flush;
	  SetStatusText(s_1_dum);

	  ifstream file_i(s_1_dum);
	  file_i.read(b_dum,76);

	  no_slices = slices_PIC(b_dum, dum_x, dum_y);    

	  char* dum5 = wxGetTextFromUser("Slice?", "Total Slices", LongToString(no_slices), this);

          if (dum5)
          {
	      StringToInt(dum5, &slice_no);

	      // THIS READS A SLICE OF THE PICTURE.
	      (frameMain->canvasMain->pp[1])->resize(1024,1024);
	      read_reduced_PIC_slice(file_i, dum_x, dum_y, slice_no, *(frameMain->canvasMain->pp[1]) );

	      // SO THAT THE CANVAS REDRAWS
	      dq.switch_redraw_canvasrun = 1;

	      // RE-DO DISPLAY LISTS AND PAINT
	      frameMain->canvasMain->DoDisplayList(1);
	      frameMain->canvasMain->OnPaint();

	      file_i.close();

	      cout << "done...!\n" << flush;
          }
      }

      break;
    }
    case FRAMEMENU_READ_BLUE:
    {
      int reduction, slice_no;
      int start_x, start_y;
      long dum_x, dum_y, no_slices;
      char b_dum[77];

      char* s_1_dum = wxFileSelector("Picture File", NULL, NULL, NULL, "*.PIC");

      if (s_1_dum)
      {
	  cout << "File read " << s_1_dum << "\n" << flush;
	  SetStatusText(s_1_dum);

	  ifstream file_i(s_1_dum);
	  file_i.read(b_dum,76);

	  no_slices = slices_PIC(b_dum, dum_x, dum_y);    

	  char* dum5 = wxGetTextFromUser("Slice?", "Total Slices", LongToString(no_slices), this);

          if (dum5)
          {
	      StringToInt(dum5, &slice_no);

	      // THIS READS A SLICE OF THE PICTURE.
	      (frameMain->canvasMain->pp[2])->resize(1024,1024);
	      read_reduced_PIC_slice(file_i, dum_x, dum_y, slice_no, *(frameMain->canvasMain->pp[2]) );

	      // SO THAT THE CANVAS REDRAWS
	      dq.switch_redraw_canvasrun = 1;

	      // RE-DO DISPLAY LISTS AND PAINT
	      frameMain->canvasMain->DoDisplayList(2);
	      frameMain->canvasMain->OnPaint();

	      file_i.close();

	      cout << "done...!\n" << flush;
          }
      }

      break;
    }
    case FRAMEMENU_OPEN:
    {
      int reduction, slice_no;
      int start_x, start_y;
      long dum_x, dum_y, no_slices;
      char b_dum[77];

      char* s_1_dum = wxFileSelector("Picture File", NULL, NULL, NULL, "*.PIC");

      if (s_1_dum)
      {
	  cout << "File read " << s_1_dum << "\n" << flush;
	  SetStatusText(s_1_dum);

	  ifstream file_i(s_1_dum);
	  file_i.read(b_dum,76);

	  no_slices = slices_PIC(b_dum, dum_x, dum_y);    

	  char* dum5 = wxGetTextFromUser("Slice?", "Total Slices", LongToString(no_slices), this);

          if (dum5)
          {
	      StringToInt(dum5, &slice_no);

	      // THIS READS A SLICE OF THE PICTURE.
	      (frameMain->canvasMain->pp[slice_no-1])->resize(1024,1024);
	      read_reduced_PIC_slice(file_i, dum_x, dum_y, slice_no, *(frameMain->canvasMain->pp[slice_no-1]) );

	      // SO THAT THE CANVAS REDRAWS
	      dq.switch_redraw_canvasrun = 1;

	      // RE-DO DISPLAY LISTS AND PAINT
	      frameMain->canvasMain->DoDisplayList(slice_no-1);
	      frameMain->canvasMain->OnPaint();

	      file_i.close();

	      cout << "done...!\n" << flush;
          }
      }

      break;
    }
    case FRAMEMENU_OPEN3:
    {
      int reduction, slice_no;
      int start_x, start_y;
      long dum_x, dum_y, no_slices;
      char b_dum[77];

      char* s_1_dum = wxFileSelector("Picture File", NULL, NULL, NULL, "*.PIC");

      if (s_1_dum)
      {
	  cout << "File read " << s_1_dum << "\n" << flush;
	  SetStatusText(s_1_dum);

	  ifstream file_i(s_1_dum);
	  file_i.read(b_dum,76);

	  no_slices = slices_PIC(b_dum, dum_x, dum_y);    

	  // THIS READS A SLICE OF THE PICTURE.
	  read_reduced_PIC_no_slices(file_i, dum_x, dum_y, 3, frameMain->canvasMain->pp );

	  // RE-DO DISPLAY LISTS AND PAINT
	  for (int i=0; i<3; i++) 
	       frameMain->canvasMain->DoDisplayList(i);

	  // SO THAT THE CANVAS REDRAWS
	  dq.switch_redraw_canvasrun = 1;

	  frameMain->canvasMain->OnPaint();

	  file_i.close();

	  cout << "done...!\n" << flush;
      }

      break;
    }
    case FRAMEMENU_KILLCHANNEL:
    {
      int kill_slice=0;
      char* dum = wxGetTextFromUser("Slice?", "Kill Slices", IntToString(kill_slice+1), this);

      if (dum)
      {
	 StringToInt(dum, &kill_slice);
         kill_slice -= 1;
         frameMain->canvasMain->DeleteDisplayList(kill_slice);
         frameMain->canvasMain->pp[kill_slice]->Clear();
	 frameMain->canvasRun->ClearCanvas();
	 frameMain->canvasMain->ClearCanvas();
	 frameMain->canvasMain->OnPaint();
      }
      break;
    }
    case FRAMEMENU_MODIFYCHANNEL:
    {
      int mask_channel=2;
      int test_channel=0;
      char* dum = wxGetTextFromUser("Mask Channel?", "Mask", IntToString(mask_channel+1), this);

      if (dum)
      {
	 StringToInt(dum, &mask_channel);
         char* dum2 = wxGetTextFromUser("Channel to Modify?", "Modify", IntToString(test_channel+1), this);
        
         if (dum2)
         {
	    StringToInt(dum2, &test_channel);
            float thres = 0.;
            char* dum3 = wxGetTextFromUser("Threshold?", "Threshold", FloatToString(thres), this);
           
            if (dum3)
            {
	       StringToFloat(dum3, &thres);
	       mask_channel -= 1;
	       test_channel -= 1;

               // DELETE DISPLAY LIST OF TEST SLICE IN ORDER TO MASK IT
	       frameMain->canvasMain->DeleteDisplayList(test_channel);
//	       frameMain->canvasMain->pp[test_channel]->Clear();

               // MASK TEST CHANNEL
               do_mask_channel
               (
	          *(frameMain->canvasMain->pp[mask_channel]),
	          *(frameMain->canvasMain->pp[test_channel]),
                  thres
               );

               // RE-DO DISPLAY LIST FOR MASKED SLICE
	       frameMain->canvasMain->DoDisplayList(test_channel);

	       // SO THAT THE CANVAS REDRAWS
	       dq.switch_redraw_canvasrun = 1;

	       frameMain->canvasRun->ClearCanvas();
	       frameMain->canvasMain->ClearCanvas();
	       frameMain->canvasMain->OnPaint();
            }
         }
      }
      break;
    }
    case FRAMEMENU_SHOW:
    {
      frameMain->Show(TRUE);
      break;
    }
    case FRAMEMENU_HIDE:
    {
      frameMain->Show(FALSE);
      break;
    }
    case FRAMEMENU_REFRESH:
    {
      frameMain->canvasMain->OnPaint();
      break;
    }
    case FRAMEMENU_CLEAR:
    {
      frameMain->canvasMain->DeleteDisplayLists();
      dq.Clear();
      for (int i=0; i<3; i++)
         frameMain->canvasMain->pp[i]->Clear();
      frameMain->canvasRun->ClearCanvas();
      frameMain->canvasMain->ClearCanvas();
      frameMain->canvasMain->OnPaint();
      break;
    }
    case FRAMEMENU_PUTINIT0:
    {
      put_init_0( *(frameMain->canvasMain->pp[0]) );
      break;
    }
    case FRAMEMENU_TEXTBOX:
    {
      // Create window, or show it if already created.
      if (!frameMain->frameText)
      {
        frameMain->frameText =
            new FrameText(this, "Data Pad", 30, 30, 850, 300, wxSDI | wxDEFAULT_FRAME, "");
      }
      frameMain->frameText->Iconize(FALSE);
      frameMain->frameText->Show(TRUE);

      break;
    }
    case FRAMEMENU_INITCOLLECT:
    {
      menuBar->Check(FRAMEMENU_INITCOLLECT,TRUE);
      menuBar->Check(FRAMEMENU_FINITCOLLECT,FALSE);
      frameMain->canvasRun->SetCursor(cursor_cross);
      dq.switch_init_data_collect = 1;
      break;
    }
    case FRAMEMENU_FINITCOLLECT:
    {
      menuBar->Check(FRAMEMENU_INITCOLLECT,FALSE);
      menuBar->Check(FRAMEMENU_FINITCOLLECT,TRUE);
      frameMain->canvasRun->SetCursor(cursor_arrow);

      dq.switch_init_data_collect = 0;
      dq.switch_first_point_data_collect = 1;

      // SO THAT THE FINISH BUTTON UPDATES THE RIGHT
      // INFINITE LIST
      if ( dq.switch_mode_curv_width == 1 )
        dq.CopyTempCoorToPermCoor();
      else if ( dq.switch_mode_curv_width == 2 )
        dq.CopyTempCoorToPermCoorWidths();
      else if ( dq.switch_mode_curv_width == 3 )
        cout << "No data to finish in Pixel Value Mode.\n" << flush;

      break;
    }
    case FRAMEMENU_CANCELCOLLECT:
    {
      menuBar->Check(FRAMEMENU_INITCOLLECT,FALSE);
      menuBar->Check(FRAMEMENU_FINITCOLLECT,FALSE);
      frameMain->canvasRun->SetCursor(cursor_arrow);

      dq.ClearLists();
      dq.switch_init_data_collect = 0;
      dq.switch_first_point_data_collect = 1;
      PRINT1("Data Collection Cancelled.");

      if ( dq.switch_mode_curv_width == 1 )
        *(frameMain->frameText->textMain) << "#\n# PREVIOUS DATA CANCELLED\n#\n";
      else if ( dq.switch_mode_curv_width == 2 )
        *(frameMain->frameText->textSecon) << "#\n# PREVIOUS DATA CANCELLED\n#\n";
      else if ( dq.switch_mode_curv_width == 3 )
        cout << "No data to cancel in Pixel Value Mode\n." << flush;

      break;
    }
    case FRAMEMENU_QUIT:
    {
      if (theApp.frameMenu)
      {
        wxFrame *fr = theApp.frameMenu;
        fr->Show(FALSE);
        fr->OnClose();  
        delete fr;
        theApp.frameMenu = NULL;
      }
      break;
    }
    case FRAMEMENU_MODECURV:
    {
      if ( menuBar->Checked(FRAMEMENU_MODEWIDTH) 
        || menuBar->Checked(FRAMEMENU_MODEVALUE) )
      {
         // OTHER INITIALIZATIONS
	 frameMain->canvasRun->SetCursor(cursor_arrow);
	 dq.switch_init_data_collect = 0;
	 dq.switch_first_point_data_collect = 1;

         PRINT1("---> CURVATURE MODE INITIALIZED.");
      }
      menuBar->Check(FRAMEMENU_MODECURV,TRUE);
      menuBar->Check(FRAMEMENU_MODEWIDTH,FALSE);
      menuBar->Check(FRAMEMENU_MODEVALUE,FALSE);
      dq.switch_mode_curv_width = 1;

      break;
    }
    case FRAMEMENU_MODEWIDTH:
    {
      if ( menuBar->Checked(FRAMEMENU_MODECURV) 
        || menuBar->Checked(FRAMEMENU_MODEVALUE) )
      {
         // OTHER INITIALIZATIONS
	 frameMain->canvasRun->SetCursor(cursor_arrow);
	 dq.switch_init_data_collect = 0;
	 dq.switch_first_point_data_collect = 1;

         PRINT1("---> WIDH MODE INITIALIZED.");
      }
      menuBar->Check(FRAMEMENU_MODEWIDTH,TRUE);
      menuBar->Check(FRAMEMENU_MODECURV,FALSE);
      menuBar->Check(FRAMEMENU_MODEVALUE,FALSE);
      dq.switch_mode_curv_width = 2;

      break;
    }
    case FRAMEMENU_MODEVALUE:
    {
      if ( menuBar->Checked(FRAMEMENU_MODECURV) 
        || menuBar->Checked(FRAMEMENU_MODEWIDTH) )
      {
         // OTHER INITIALIZATIONS
	 frameMain->canvasRun->SetCursor(cursor_value);
//	 dq.switch_init_data_collect = 0;
//	 dq.switch_first_point_data_collect = 1;

         PRINT1("---> PIXEL VALUE MODE.");
      }
      menuBar->Check(FRAMEMENU_MODEWIDTH,FALSE);
      menuBar->Check(FRAMEMENU_MODECURV,FALSE);
      menuBar->Check(FRAMEMENU_MODEVALUE,TRUE);
      dq.switch_mode_curv_width = 3;

      break;
    }
    case FRAMEMENU_SETUP: 
    {
      TabFoldersSetup(this);
      break;
    }
    default:
    {
      cout << "Bad in buttons, FrameMenu.\n" << flush;
      break;
    }
  }
}

/*
======================================================================
*/
