
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#include <stdlib.h>
#include <time.h>

#include "Text.h"
#include "data.h"
#include "macros.h"

#include "wx_dialg.h"
/* CMDLG
*/
#include "wb_cmdlg.h"

extern data dq;

FrameText::FrameText(wxFrame *parent, char *title, int x, int y, int width, int height, long style, char *name):
  wxFrame(parent, title, x, y, width, height, style, name)
{
  // Initialize child subwindow members.
  textMain = NULL;
  textSecon = NULL;

  menuText = NULL;

  menuText = new wxMenuBar;

  wxMenu *menuFile = new wxMenu;
//menuFile->Append(TEXTFILE_OPEN, "Open");
  menuFile->Append(TEXTFILE_SAVEAS, "Save As...");
//menuFile->AppendSeparator();
//menuFile->Append(TEXTFILE_SAVEXMGR, "Save As Xmgr...");
  menuText->Append(menuFile, "File");
  
  wxMenu *menuEdit = new wxMenu;
  menuEdit->Append(TEXTEDIT_COPY, "Copy");
  menuEdit->Append(TEXTEDIT_CUT, "Cut");
  menuEdit->Append(TEXTEDIT_PASTE, "Paste");
  menuEdit->AppendSeparator();
  menuEdit->Append(TEXTEDIT_CLEARALL, "Clear All");
  menuText->Append(menuEdit, "Edit");

  SetMenuBar(menuText);

  textWindowFont = new wxFont(12, wxSWISS, wxNORMAL, wxNORMAL);


/* =======================>>>>>>>>>>>>>>>>>>>>>>========================= */

  textMain = new TextMain(this, 0, 0, 900, 300, 0, "textMain");
  textMain->SetFont(textWindowFont);

  textSecon = new TextMain(this, 0, 300, 900, 300, 0, "");
  textSecon->SetFont(textWindowFont);

/* =======================<<<<<<<<<<<<<<<<<<<<<<========================= */

  // Ensure the subwindows get resized o.k.
  OnSize(width, height);

  // Centre frame on the screen.
//Centre(wxBOTH);

  // Show the frame.
  Show(TRUE);
}

FrameText::~FrameText(void)
{
}

Bool FrameText::OnClose(void)
{
  // Clean up any associated data here.
  return TRUE;
}

void FrameText::OnSize(int w, int h)
{
  // Let default member handle sizing for only one subwindow.
  wxFrame::OnSize(w, h);
}

void FrameText::OnMenuCommand(int commandId)
{
  switch (commandId)
  {
     // Load File
     case TEXTFILE_OPEN:
     {
        char *s = wxFileSelector("Load file", NULL, NULL, NULL, "*.*");

        if (s)
        {
          if ( dq.switch_mode_curv_width == 1 )
           textMain->LoadFile(s);
          else if ( dq.switch_mode_curv_width == 2 )
           textSecon->LoadFile(s);
          else if ( dq.switch_mode_curv_width == 3 )
           cout << "Have to Choose Width or Curvature Mode.\n" << flush;
        }

	break;
     }
     // Save to File
     case TEXTFILE_SAVEAS:
     {
        char *s = wxFileSelector("Load file", NULL, NULL, NULL, "*.*");

        if (s) 
        {
          if ( dq.switch_mode_curv_width == 1 )
           textMain->SaveFile(s);
          else if ( dq.switch_mode_curv_width == 2 )
           textSecon->SaveFile(s);
          else if ( dq.switch_mode_curv_width == 3 )
           cout << "Have to Choose Width or Curvature Mode.\n" << flush;
        }

	break;
     }
     // Save to File
     case TEXTFILE_SAVEXMGR:
     {
        char *s = wxFileSelector("Save As XMGR", NULL, NULL, NULL, "*.*");
        
        if (s) 
        {
          if ( dq.switch_mode_curv_width == 1 )
          {
            ofstream file_o(s);
            textMain->OutputXmgr(file_o);
            file_o.close();
            cout << "File saved...!\n";
          }
          else if ( dq.switch_mode_curv_width == 2 )
          {
            PRINT1("NO Xmgr SAVE IN WIDTH MODE");
          }
          else if ( dq.switch_mode_curv_width == 3 )
          {
            PRINT1("NO Xmgr SAVE IN PIXEL MODE");
          }
        }

	break;
     }
     // Copy Selection into Clipboard
     case TEXTEDIT_COPY:
     {
          if ( dq.switch_mode_curv_width == 1 )
	     textMain->Copy();
          else if ( dq.switch_mode_curv_width == 2 )
	     textSecon->Copy();
          else if ( dq.switch_mode_curv_width == 3 )
             cout << "Have to Choose Width or Curvature Mode.\n" << flush;
	  break;
     }
     // Cuts Selection into Clipboard
     case TEXTEDIT_CUT:
     {
          if ( dq.switch_mode_curv_width == 1 )
 	   textMain->Cut();
          else if ( dq.switch_mode_curv_width == 2 )
 	   textSecon->Cut();
          else if ( dq.switch_mode_curv_width == 3 )
           cout << "Have to Choose Width or Curvature Mode.\n" << flush;
 	  break;
     }
     // Pastes Selection from Clipboard
     case TEXTEDIT_PASTE:
     {
          if ( dq.switch_mode_curv_width == 1 )
      	   textMain->Paste();
          else if ( dq.switch_mode_curv_width == 2 )
      	   textSecon->Paste();
          else if ( dq.switch_mode_curv_width == 3 )
           cout << "Have to Choose Width or Curvature Mode.\n" << flush;
	  break;
     }
     case TEXTEDIT_CLEARALL:
     {
          if ( dq.switch_mode_curv_width == 1 )
      	   textMain->Clear();
          else if ( dq.switch_mode_curv_width == 2 )
      	   textSecon->Clear();
	  break;
     }

     default:
       	break;
  }
}

TextMain::TextMain(wxFrame *parent, int x, int y, int width, int height, long style, char *name):
  wxTextWindow(parent, x, y, width, height, style, name)
{
}

TextMain::~TextMain(void)
{
}

void TextMain::OnSize(int w, int h)
{
  wxTextWindow::OnSize(w, h);
}

void TextMain::OutputXmgr(ofstream &out_file)
{
 // DATA IS 673 LINES DOWN

 out_file << "# xmgr parameter file                                \n"
	  << "#                                                    \n"
	  << "#                                                    \n"
	  << "@page layout portrait                                \n"
	  << "@ps linewidth begin 1                                \n"
	  << "@ps linewidth increment 2                            \n"
	  << "@hardcopy device 1                                   \n"
	  << "@page 5                                              \n"
	  << "@page inout 5                                        \n"
	  << "@link page off                                       \n"
	  << "@default linestyle 1                                 \n"
	  << "@default linewidth 1                                 \n"
	  << "@default color 1                                     \n"
	  << "@default char size 1.000000                          \n"
	  << "@default font 4                                      \n"
	  << "@default font source 0                               \n"
	  << "@default symbol size 1.000000                        \n"
	  << "@with string                                         \n"
	  << "@    string on                                       \n"
	  << "@    string loctype view                             \n"
	  << "@    string 0.188858695652, 0.4039408867             \n"
	  << "@    string linewidth 1                              \n"
	  << "@    string color 1                                  \n"
	  << "@    string rot 0                                    \n"
	  << "@    string font 5                                   \n"
	  << "@    string just 0                                   \n"
	  << "@    string char size 0.850000                       \n"
	  << "@string def \"\\5\"                                     \n"
	  << "@with g0                                             \n"
	  << "@g0 on                                               \n"
	  << "@g0 label off                                        \n"
	  << "@g0 hidden false                                     \n"
	  << "@g0 type xy                                          \n"
	  << "@g0 autoscale type AUTO                              \n"
	  << "@g0 fixedpoint off                                   \n"
	  << "@g0 fixedpoint type 0                                \n"
	  << "@g0 fixedpoint xy 0.000000, 0.000000                 \n"
	  << "@g0 fixedpoint format general general                \n"
	  << "@g0 fixedpoint prec 6, 6                             \n"
	  << "@    world xmin 0                                    \n"
	  << "@    world xmax 600                                  \n"
	  << "@    world ymin 0                                    \n"
	  << "@    world ymax 500                                  \n"
	  << "@    stack world 0, 0, 0, 0 tick 0, 0, 0, 0          \n"
	  << "@    stack world 0, 0, 0, 0 tick 0, 0, 0, 0          \n"
	  << "@    view xmin 0.150000                              \n"
	  << "@    view xmax 0.850000                              \n"
	  << "@    view ymin 0.550000                              \n"
	  << "@    view ymax 0.850000                              \n"
	  << "@    title \"\"                                        \n"
	  << "@    title font 4                                    \n"
	  << "@    title size 1.500000                             \n"
	  << "@    title color 1                                   \n"
	  << "@    title linewidth 1                               \n"
	  << "@    subtitle \"\"                                     \n"
	  << "@    subtitle font 4                                 \n"
	  << "@    subtitle size 1.000000                          \n"
	  << "@    subtitle color 1                                \n"
	  << "@    subtitle linewidth 1                            \n"
	  << "@    s0 symbol 2                                     \n"
	  << "@    s0 symbol size 0.590000                         \n"
	  << "@    s0 symbol fill 1                                \n"
	  << "@    s0 symbol color 1                               \n"
	  << "@    s0 symbol linewidth 1                           \n"
	  << "@    s0 symbol linestyle 1                           \n"
	  << "@    s0 symbol center false                          \n"
	  << "@    s0 symbol char 0                                \n"
	  << "@    s0 skip 0                                       \n"
	  << "@    s0 linestyle 0                                  \n"
	  << "@    s0 linewidth 1                                  \n"
	  << "@    s0 color 1                                      \n"
	  << "@    s0 fill 0                                       \n"
	  << "@    s0 fill with color                              \n"
	  << "@    s0 fill color 1                                 \n"
	  << "@    s0 fill pattern 0                               \n"
	  << "@    s0 errorbar type BOTH                           \n"
	  << "@    s0 errorbar length 1.000000                     \n"
	  << "@    s0 errorbar linewidth 1                         \n"
	  << "@    s0 errorbar linestyle 1                         \n"
	  << "@    s0 errorbar riser on                            \n"
	  << "@    s0 errorbar riser linewidth 1                   \n"
	  << "@    s0 errorbar riser linestyle 1                   \n"
	  << "@    s0 xyz 0.000000, 0.000000                       \n"
	  << "@    s0 comment \"\"                   \n"
	  << "@    s1 symbol 5                                     \n"
	  << "@    s1 symbol size 0.590000                         \n"
	  << "@    s1 symbol fill 1                                \n"
	  << "@    s1 symbol color 1                               \n"
	  << "@    s1 symbol linewidth 1                           \n"
	  << "@    s1 symbol linestyle 1                           \n"
	  << "@    s1 symbol center false                          \n"
	  << "@    s1 symbol char 0                                \n"
	  << "@    s1 skip 0                                       \n"
	  << "@    s1 linestyle 0                                  \n"
	  << "@    s1 linewidth 1                                  \n"
	  << "@    s1 color 1                                      \n"
	  << "@    s1 fill 0                                       \n"
	  << "@    s1 fill with color                              \n"
	  << "@    s1 fill color 1                                 \n"
	  << "@    s1 fill pattern 0                               \n"
	  << "@    s1 errorbar type BOTH                           \n"
	  << "@    s1 errorbar length 1.000000                     \n"
	  << "@    s1 errorbar linewidth 1                         \n"
	  << "@    s1 errorbar linestyle 1                         \n"
	  << "@    s1 errorbar riser on                            \n"
	  << "@    s1 errorbar riser linewidth 1                   \n"
	  << "@    s1 errorbar riser linestyle 1                   \n"
	  << "@    s1 xyz 0.000000, 0.000000                       \n"
	  << "@    s1 comment \"\"                   \n"
	  << "@    xaxis  tick on                                  \n"
	  << "@    xaxis  tick major 100                           \n"
	  << "@    xaxis  tick minor 100                           \n"
	  << "@    xaxis  tick offsetx 0.000000                    \n"
	  << "@    xaxis  tick offsety 0.000000                    \n"
	  << "@    xaxis  label \"\\5length of dendrite l\"           \n"
	  << "@    xaxis  label layout para                        \n"
	  << "@    xaxis  label place auto                         \n"
	  << "@    xaxis  label char size 0.850000                 \n"
	  << "@    xaxis  label font 5                             \n"
	  << "@    xaxis  label color 1                            \n"
	  << "@    xaxis  label linewidth 2                        \n"
	  << "@    xaxis  ticklabel on                             \n"
	  << "@    xaxis  ticklabel type auto                      \n"
	  << "@    xaxis  ticklabel prec 0                         \n"
	  << "@    xaxis  ticklabel format decimal                 \n"
	  << "@    xaxis  ticklabel append \"\"                      \n"
	  << "@    xaxis  ticklabel prepend \"\"                     \n"
	  << "@    xaxis  ticklabel layout horizontal              \n"
	  << "@    xaxis  ticklabel skip 0                         \n"
	  << "@    xaxis  ticklabel stagger 0                      \n"
	  << "@    xaxis  ticklabel op bottom                      \n"
	  << "@    xaxis  ticklabel sign normal                    \n"
	  << "@    xaxis  ticklabel start type auto                \n"
	  << "@    xaxis  ticklabel start 0.000000                 \n"
	  << "@    xaxis  ticklabel stop type auto                 \n"
	  << "@    xaxis  ticklabel stop 0.000000                  \n"
	  << "@    xaxis  ticklabel char size 0.820000             \n"
	  << "@    xaxis  ticklabel font 5                         \n"
	  << "@    xaxis  ticklabel color 1                        \n"
	  << "@    xaxis  ticklabel linewidth 2                    \n"
	  << "@    xaxis  tick major on                            \n"
	  << "@    xaxis  tick minor on                            \n"
	  << "@    xaxis  tick default 6                           \n"
	  << "@    xaxis  tick in                                  \n"
	  << "@    xaxis  tick major color 1                       \n"
	  << "@    xaxis  tick major linewidth 2                   \n"
	  << "@    xaxis  tick major linestyle 1                   \n"
	  << "@    xaxis  tick minor color 1                       \n"
	  << "@    xaxis  tick minor linewidth 2                   \n"
	  << "@    xaxis  tick minor linestyle 1                   \n"
	  << "@    xaxis  tick log off                             \n"
	  << "@    xaxis  tick size 1.000000                       \n"
	  << "@    xaxis  tick minor size 0.500000                 \n"
	  << "@    xaxis  bar off                                  \n"
	  << "@    xaxis  bar color 1                              \n"
	  << "@    xaxis  bar linestyle 1                          \n"
	  << "@    xaxis  bar linewidth 1                          \n"
	  << "@    xaxis  tick major grid off                      \n"
	  << "@    xaxis  tick minor grid off                      \n"
	  << "@    xaxis  tick op both                             \n"
	  << "@    xaxis  tick type auto                           \n"
	  << "@    xaxis  tick spec 0                              \n"
	  << "@    yaxis  tick on                                  \n"
	  << "@    yaxis  tick major 100                           \n"
	  << "@    yaxis  tick minor 100                           \n"
	  << "@    yaxis  tick offsetx 0.000000                    \n"
	  << "@    yaxis  tick offsety 0.000000                    \n"
	  << "@    yaxis  label \"\\5D(l) & R\\sG\\N\\5(l)\"             \n"
	  << "@    yaxis  label layout para                        \n"
	  << "@    yaxis  label place auto                         \n"
	  << "@    yaxis  label char size 0.850000                 \n"
	  << "@    yaxis  label font 5                             \n"
	  << "@    yaxis  label color 1                            \n"
	  << "@    yaxis  label linewidth 2                        \n"
	  << "@    yaxis  ticklabel on                             \n"
	  << "@    yaxis  ticklabel type auto                      \n"
	  << "@    yaxis  ticklabel prec 0                         \n"
	  << "@    yaxis  ticklabel format decimal                 \n"
	  << "@    yaxis  ticklabel append \"\"                      \n"
	  << "@    yaxis  ticklabel prepend \"\"                     \n"
	  << "@    yaxis  ticklabel layout horizontal              \n"
	  << "@    yaxis  ticklabel skip 0                         \n"
	  << "@    yaxis  ticklabel stagger 0                      \n"
	  << "@    yaxis  ticklabel op left                        \n"
	  << "@    yaxis  ticklabel sign normal                    \n"
	  << "@    yaxis  ticklabel start type auto                \n"
	  << "@    yaxis  ticklabel start 0.000000                 \n"
	  << "@    yaxis  ticklabel stop type auto                 \n"
	  << "@    yaxis  ticklabel stop 0.000000                  \n"
	  << "@    yaxis  ticklabel char size 0.820000             \n"
	  << "@    yaxis  ticklabel font 5                         \n"
	  << "@    yaxis  ticklabel color 1                        \n"
	  << "@    yaxis  ticklabel linewidth 2                    \n"
	  << "@    yaxis  tick major on                            \n"
	  << "@    yaxis  tick minor on                            \n"
	  << "@    yaxis  tick default 6                           \n"
	  << "@    yaxis  tick in                                  \n"
	  << "@    yaxis  tick major color 1                       \n"
	  << "@    yaxis  tick major linewidth 2                   \n"
	  << "@    yaxis  tick major linestyle 1                   \n"
	  << "@    yaxis  tick minor color 1                       \n"
	  << "@    yaxis  tick minor linewidth 2                   \n"
	  << "@    yaxis  tick minor linestyle 1                   \n"
	  << "@    yaxis  tick log off                             \n"
	  << "@    yaxis  tick size 1.000000                       \n"
	  << "@    yaxis  tick minor size 0.500000                 \n"
	  << "@    yaxis  bar off                                  \n"
	  << "@    yaxis  bar color 1                              \n"
	  << "@    yaxis  bar linestyle 1                          \n"
	  << "@    yaxis  bar linewidth 1                          \n"
	  << "@    yaxis  tick major grid off                      \n"
	  << "@    yaxis  tick minor grid off                      \n"
	  << "@    yaxis  tick op both                             \n"
	  << "@    yaxis  tick type auto                           \n"
	  << "@    yaxis  tick spec 0                              \n"
	  << "@    zeroxaxis  tick on                              \n"
	  << "@    zeroxaxis  tick major 200                       \n"
	  << "@    zeroxaxis  tick minor 100                       \n"
	  << "@    zeroxaxis  tick offsetx 0.000000                \n"
	  << "@    zeroxaxis  tick offsety 0.000000                \n"
	  << "@    zeroxaxis  label \"\"                             \n"
	  << "@    zeroxaxis  label layout para                    \n"
	  << "@    zeroxaxis  label place auto                     \n"
	  << "@    zeroxaxis  label char size 1.000000             \n"
	  << "@    zeroxaxis  label font 4                         \n"
	  << "@    zeroxaxis  label color 1                        \n"
	  << "@    zeroxaxis  label linewidth 1                    \n"
	  << "@    zeroxaxis  ticklabel off                        \n"
	  << "@    zeroxaxis  ticklabel type auto                  \n"
	  << "@    zeroxaxis  ticklabel prec 1                     \n"
	  << "@    zeroxaxis  ticklabel format decimal             \n"
	  << "@    zeroxaxis  ticklabel append \"\"                  \n"
	  << "@    zeroxaxis  ticklabel prepend \"\"                 \n"
	  << "@    zeroxaxis  ticklabel layout horizontal          \n"
	  << "@    zeroxaxis  ticklabel skip 0                     \n"
	  << "@    zeroxaxis  ticklabel stagger 0                  \n"
	  << "@    zeroxaxis  ticklabel op bottom                  \n"
	  << "@    zeroxaxis  ticklabel sign normal                \n"
	  << "@    zeroxaxis  ticklabel start type auto            \n"
	  << "@    zeroxaxis  ticklabel start 0.000000             \n"
	  << "@    zeroxaxis  ticklabel stop type auto             \n"
	  << "@    zeroxaxis  ticklabel stop 0.000000              \n"
	  << "@    zeroxaxis  ticklabel char size 1.000000         \n"
	  << "@    zeroxaxis  ticklabel font 4                     \n"
	  << "@    zeroxaxis  ticklabel color 1                    \n"
	  << "@    zeroxaxis  ticklabel linewidth 1                \n"
	  << "@    zeroxaxis  tick major off                       \n"
	  << "@    zeroxaxis  tick minor on                        \n"
	  << "@    zeroxaxis  tick default 6                       \n"
	  << "@    zeroxaxis  tick in                              \n"
	  << "@    zeroxaxis  tick major color 1                   \n"
	  << "@    zeroxaxis  tick major linewidth 1               \n"
	  << "@    zeroxaxis  tick major linestyle 1               \n"
	  << "@    zeroxaxis  tick minor color 1                   \n"
	  << "@    zeroxaxis  tick minor linewidth 1               \n"
	  << "@    zeroxaxis  tick minor linestyle 1               \n"
	  << "@    zeroxaxis  tick log off                         \n"
	  << "@    zeroxaxis  tick size 1.000000                   \n"
	  << "@    zeroxaxis  tick minor size 0.500000             \n"
	  << "@    zeroxaxis  bar off                              \n"
	  << "@    zeroxaxis  bar color 1                          \n"
	  << "@    zeroxaxis  bar linestyle 1                      \n"
	  << "@    zeroxaxis  bar linewidth 1                      \n"
	  << "@    zeroxaxis  tick major grid off                  \n"
	  << "@    zeroxaxis  tick minor grid off                  \n"
	  << "@    zeroxaxis  tick op both                         \n"
	  << "@    zeroxaxis  tick type auto                       \n"
	  << "@    zeroxaxis  tick spec 0                          \n"
	  << "@    zeroyaxis  tick on                              \n"
	  << "@    zeroyaxis  tick major 100                       \n"
	  << "@    zeroyaxis  tick minor 50                        \n"
	  << "@    zeroyaxis  tick offsetx 0.000000                \n"
	  << "@    zeroyaxis  tick offsety 0.000000                \n"
	  << "@    zeroyaxis  label \"\"                             \n"
	  << "@    zeroyaxis  label layout para                    \n"
	  << "@    zeroyaxis  label place auto                     \n"
	  << "@    zeroyaxis  label char size 1.000000             \n"
	  << "@    zeroyaxis  label font 4                         \n"
	  << "@    zeroyaxis  label color 1                        \n"
	  << "@    zeroyaxis  label linewidth 1                    \n"
	  << "@    zeroyaxis  ticklabel off                        \n"
	  << "@    zeroyaxis  ticklabel type auto                  \n"
	  << "@    zeroyaxis  ticklabel prec 3                     \n"
	  << "@    zeroyaxis  ticklabel format decimal             \n"
	  << "@    zeroyaxis  ticklabel append \"\"                  \n"
	  << "@    zeroyaxis  ticklabel prepend \"\"                 \n"
	  << "@    zeroyaxis  ticklabel layout horizontal          \n"
	  << "@    zeroyaxis  ticklabel skip 0                     \n"
	  << "@    zeroyaxis  ticklabel stagger 0                  \n"
	  << "@    zeroyaxis  ticklabel op left                    \n"
	  << "@    zeroyaxis  ticklabel sign normal                \n"
	  << "@    zeroyaxis  ticklabel start type auto            \n"
	  << "@    zeroyaxis  ticklabel start 0.000000             \n"
	  << "@    zeroyaxis  ticklabel stop type auto             \n"
	  << "@    zeroyaxis  ticklabel stop 0.000000              \n"
	  << "@    zeroyaxis  ticklabel char size 1.000000         \n"
	  << "@    zeroyaxis  ticklabel font 4                     \n"
	  << "@    zeroyaxis  ticklabel color 1                    \n"
	  << "@    zeroyaxis  ticklabel linewidth 1                \n"
	  << "@    zeroyaxis  tick major off                       \n"
	  << "@    zeroyaxis  tick minor on                        \n"
	  << "@    zeroyaxis  tick default 6                       \n"
	  << "@    zeroyaxis  tick in                              \n"
	  << "@    zeroyaxis  tick major color 1                   \n"
	  << "@    zeroyaxis  tick major linewidth 1               \n"
	  << "@    zeroyaxis  tick major linestyle 1               \n"
	  << "@    zeroyaxis  tick minor color 1                   \n"
	  << "@    zeroyaxis  tick minor linewidth 1               \n"
	  << "@    zeroyaxis  tick minor linestyle 1               \n"
	  << "@    zeroyaxis  tick log off                         \n"
	  << "@    zeroyaxis  tick size 1.000000                   \n"
	  << "@    zeroyaxis  tick minor size 0.500000             \n"
	  << "@    zeroyaxis  bar off                              \n"
	  << "@    zeroyaxis  bar color 1                          \n"
	  << "@    zeroyaxis  bar linestyle 1                      \n"
	  << "@    zeroyaxis  bar linewidth 1                      \n"
	  << "@    zeroyaxis  tick major grid off                  \n"
	  << "@    zeroyaxis  tick minor grid off                  \n"
	  << "@    zeroyaxis  tick op both                         \n"
	  << "@    zeroyaxis  tick type auto                       \n"
	  << "@    zeroyaxis  tick spec 0                          \n"
	  << "@    legend on                                       \n"
	  << "@    legend loctype view                             \n"
	  << "@    legend layout 0                                 \n"
	  << "@    legend vgap 2                                   \n"
	  << "@    legend hgap 1                                   \n"
	  << "@    legend length 4                                 \n"
	  << "@    legend box off                                  \n"
	  << "@    legend box fill off                             \n"
	  << "@    legend box fill with color                      \n"
	  << "@    legend box fill color 0                         \n"
	  << "@    legend box fill pattern 1                       \n"
	  << "@    legend box color 1                              \n"
	  << "@    legend box linewidth 1                          \n"
	  << "@    legend box linestyle 1                          \n"
	  << "@    legend x1 0.169837                              \n"
	  << "@    legend y1 0.812808                              \n"
	  << "@    legend font 5                                   \n"
	  << "@    legend char size 0.880000                       \n"
	  << "@    legend linestyle 1                              \n"
	  << "@    legend linewidth 1                              \n"
	  << "@    legend color 1                                  \n"
	  << "@    legend string 0 \"\\5D(l)\"                        \n"
	  << "@    legend string 1 \"\\5R\\sG\\N\\5(l)\"                 \n"
	  << "@    frame on                                        \n"
	  << "@    frame type 0                                    \n"
	  << "@    frame linestyle 1                               \n"
	  << "@    frame linewidth 2                               \n"
	  << "@    frame color 1                                   \n"
	  << "@    frame fill off                                  \n"
	  << "@    frame background color 0                        \n"
	  << "@with g1                                             \n"
	  << "@g1 on                                               \n"
	  << "@g1 label off                                        \n"
	  << "@g1 hidden false                                     \n"
	  << "@g1 type xy                                          \n"
	  << "@g1 autoscale type AUTO                              \n"
	  << "@g1 fixedpoint off                                   \n"
	  << "@g1 fixedpoint type 0                                \n"
	  << "@g1 fixedpoint xy 0.000000, 0.000000                 \n"
	  << "@g1 fixedpoint format general general                \n"
	  << "@g1 fixedpoint prec 6, 6                             \n"
	  << "@    world xmin 0                                    \n"
	  << "@    world xmax 3000                                 \n"
	  << "@    world ymin 0                                    \n"
	  << "@    world ymax 0.01                                 \n"
	  << "@    stack world 0, 0, 0, 0 tick 0, 0, 0, 0          \n"
	  << "@    stack world 0, 0, 0, 0 tick 0, 0, 0, 0          \n"
	  << "@    view xmin 0.150000                              \n"
	  << "@    view xmax 0.850000                              \n"
	  << "@    view ymin 0.150000                              \n"
	  << "@    view ymax 0.450000                              \n"
	  << "@    title \"\"                                        \n"
	  << "@    title font 4                                    \n"
	  << "@    title size 1.500000                             \n"
	  << "@    title color 1                                   \n"
	  << "@    title linewidth 1                               \n"
	  << "@    subtitle \"\"                                     \n"
	  << "@    subtitle font 4                                 \n"
	  << "@    subtitle size 1.000000                          \n"
	  << "@    subtitle color 1                                \n"
	  << "@    subtitle linewidth 1                            \n"
	  << "@    s0 symbol 3                                     \n"
	  << "@    s0 symbol size 0.640000                         \n"
	  << "@    s0 symbol fill 0                                \n"
	  << "@    s0 symbol color 1                               \n"
	  << "@    s0 symbol linewidth 2                           \n"
	  << "@    s0 symbol linestyle 1                           \n"
	  << "@    s0 symbol center false                          \n"
	  << "@    s0 symbol char 0                                \n"
	  << "@    s0 skip 0                                       \n"
	  << "@    s0 linestyle 1                                  \n"
	  << "@    s0 linewidth 1                                  \n"
	  << "@    s0 color 1                                      \n"
	  << "@    s0 fill 0                                       \n"
	  << "@    s0 fill with color                              \n"
	  << "@    s0 fill color 1                                 \n"
	  << "@    s0 fill pattern 0                               \n"
	  << "@    s0 errorbar type BOTH                           \n"
	  << "@    s0 errorbar length 1.000000                     \n"
	  << "@    s0 errorbar linewidth 1                         \n"
	  << "@    s0 errorbar linestyle 1                         \n"
	  << "@    s0 errorbar riser on                            \n"
	  << "@    s0 errorbar riser linewidth 1                   \n"
	  << "@    s0 errorbar riser linestyle 1                   \n"
	  << "@    s0 xyz 0.000000, 0.000000                       \n"
	  << "@    s0 comment \"Cols 1 4\"                           \n"
	  << "@    s1 symbol 2                                     \n"
	  << "@    s1 symbol size 0.740000                         \n"
	  << "@    s1 symbol fill 0                                \n"
	  << "@    s1 symbol color 1                               \n"
	  << "@    s1 symbol linewidth 2                           \n"
	  << "@    s1 symbol linestyle 1                           \n"
	  << "@    s1 symbol center false                          \n"
	  << "@    s1 symbol char 0                                \n"
	  << "@    s1 skip 0                                       \n"
	  << "@    s1 linestyle 1                                  \n"
	  << "@    s1 linewidth 1                                  \n"
	  << "@    s1 color 1                                      \n"
	  << "@    s1 fill 0                                       \n"
	  << "@    s1 fill with color                              \n"
	  << "@    s1 fill color 1                                 \n"
	  << "@    s1 fill pattern 0                               \n"
	  << "@    s1 errorbar type BOTH                           \n"
	  << "@    s1 errorbar length 1.000000                     \n"
	  << "@    s1 errorbar linewidth 1                         \n"
	  << "@    s1 errorbar linestyle 1                         \n"
	  << "@    s1 errorbar riser on                            \n"
	  << "@    s1 errorbar riser linewidth 1                   \n"
	  << "@    s1 errorbar riser linestyle 1                   \n"
	  << "@    s1 xyz 0.000000, 0.000000                       \n"
	  << "@    s1 comment \"Cols 1 5\"                           \n"
	  << "@    xaxis  tick on                                  \n"
	  << "@    xaxis  tick major 1000                          \n"
	  << "@    xaxis  tick minor 500                           \n"
	  << "@    xaxis  tick offsetx 0.000000                    \n"
	  << "@    xaxis  tick offsety 0.000000                    \n"
	  << "@    xaxis  label \"\\5length of dendrite l\"           \n"
	  << "@    xaxis  label layout para                        \n"
	  << "@    xaxis  label place auto                         \n"
	  << "@    xaxis  label char size 0.850000                 \n"
	  << "@    xaxis  label font 5                             \n"
	  << "@    xaxis  label color 1                            \n"
	  << "@    xaxis  label linewidth 2                        \n"
	  << "@    xaxis  ticklabel on                             \n"
	  << "@    xaxis  ticklabel type auto                      \n"
	  << "@    xaxis  ticklabel prec 0                         \n"
	  << "@    xaxis  ticklabel format decimal                 \n"
	  << "@    xaxis  ticklabel append \"\"                      \n"
	  << "@    xaxis  ticklabel prepend \"\"                     \n"
	  << "@    xaxis  ticklabel layout horizontal              \n"
	  << "@    xaxis  ticklabel skip 0                         \n"
	  << "@    xaxis  ticklabel stagger 0                      \n"
	  << "@    xaxis  ticklabel op bottom                      \n"
	  << "@    xaxis  ticklabel sign normal                    \n"
	  << "@    xaxis  ticklabel start type auto                \n"
	  << "@    xaxis  ticklabel start 0.000000                 \n"
	  << "@    xaxis  ticklabel stop type auto                 \n"
	  << "@    xaxis  ticklabel stop 0.000000                  \n"
	  << "@    xaxis  ticklabel char size 0.820000             \n"
	  << "@    xaxis  ticklabel font 5                         \n"
	  << "@    xaxis  ticklabel color 1                        \n"
	  << "@    xaxis  ticklabel linewidth 2                    \n"
	  << "@    xaxis  tick major on                            \n"
	  << "@    xaxis  tick minor on                            \n"
	  << "@    xaxis  tick default 6                           \n"
	  << "@    xaxis  tick in                                  \n"
	  << "@    xaxis  tick major color 1                       \n"
	  << "@    xaxis  tick major linewidth 2                   \n"
	  << "@    xaxis  tick major linestyle 1                   \n"
	  << "@    xaxis  tick minor color 1                       \n"
	  << "@    xaxis  tick minor linewidth 2                   \n"
	  << "@    xaxis  tick minor linestyle 1                   \n"
	  << "@    xaxis  tick log off                             \n"
	  << "@    xaxis  tick size 1.000000                       \n"
	  << "@    xaxis  tick minor size 0.500000                 \n"
	  << "@    xaxis  bar off                                  \n"
	  << "@    xaxis  bar color 1                              \n"
	  << "@    xaxis  bar linestyle 1                          \n"
	  << "@    xaxis  bar linewidth 1                          \n"
	  << "@    xaxis  tick major grid off                      \n"
	  << "@    xaxis  tick minor grid off                      \n"
	  << "@    xaxis  tick op both                             \n"
	  << "@    xaxis  tick type auto                           \n"
	  << "@    xaxis  tick spec 0                              \n"
	  << "@    yaxis  tick on                                  \n"
	  << "@    yaxis  tick major 0.002                         \n"
	  << "@    yaxis  tick minor 0.001                         \n"
	  << "@    yaxis  tick offsetx 0.000000                    \n"
	  << "@    yaxis  tick offsety 0.000000                    \n"
	  << "@    yaxis  label \"\\5Curvature\"                      \n"
	  << "@    yaxis  label layout para                        \n"
	  << "@    yaxis  label place auto                         \n"
	  << "@    yaxis  label char size 0.850000                 \n"
	  << "@    yaxis  label font 5                             \n"
	  << "@    yaxis  label color 1                            \n"
	  << "@    yaxis  label linewidth 2                        \n"
	  << "@    yaxis  ticklabel on                             \n"
	  << "@    yaxis  ticklabel type auto                      \n"
	  << "@    yaxis  ticklabel prec 3                         \n"
	  << "@    yaxis  ticklabel format decimal                 \n"
	  << "@    yaxis  ticklabel append \"\"                      \n"
	  << "@    yaxis  ticklabel prepend \"\"                     \n"
	  << "@    yaxis  ticklabel layout horizontal              \n"
	  << "@    yaxis  ticklabel skip 0                         \n"
	  << "@    yaxis  ticklabel stagger 0                      \n"
	  << "@    yaxis  ticklabel op left                        \n"
	  << "@    yaxis  ticklabel sign normal                    \n"
	  << "@    yaxis  ticklabel start type auto                \n"
	  << "@    yaxis  ticklabel start 0.000000                 \n"
	  << "@    yaxis  ticklabel stop type auto                 \n"
	  << "@    yaxis  ticklabel stop 0.000000                  \n"
	  << "@    yaxis  ticklabel char size 0.820000             \n"
	  << "@    yaxis  ticklabel font 5                         \n"
	  << "@    yaxis  ticklabel color 1                        \n"
	  << "@    yaxis  ticklabel linewidth 2                    \n"
	  << "@    yaxis  tick major on                            \n"
	  << "@    yaxis  tick minor on                            \n"
	  << "@    yaxis  tick default 6                           \n"
	  << "@    yaxis  tick in                                  \n"
	  << "@    yaxis  tick major color 1                       \n"
	  << "@    yaxis  tick major linewidth 2                   \n"
	  << "@    yaxis  tick major linestyle 1                   \n"
	  << "@    yaxis  tick minor color 1                       \n"
	  << "@    yaxis  tick minor linewidth 2                   \n"
	  << "@    yaxis  tick minor linestyle 1                   \n"
	  << "@    yaxis  tick log off                             \n"
	  << "@    yaxis  tick size 1.000000                       \n"
	  << "@    yaxis  tick minor size 0.500000                 \n"
	  << "@    yaxis  bar off                                  \n"
	  << "@    yaxis  bar color 1                              \n"
	  << "@    yaxis  bar linestyle 1                          \n"
	  << "@    yaxis  bar linewidth 1                          \n"
	  << "@    yaxis  tick major grid off                      \n"
	  << "@    yaxis  tick minor grid off                      \n"
	  << "@    yaxis  tick op both                             \n"
	  << "@    yaxis  tick type auto                           \n"
	  << "@    yaxis  tick spec 0                              \n"
	  << "@    zeroxaxis  tick on                              \n"
	  << "@    zeroxaxis  tick major 1000                      \n"
	  << "@    zeroxaxis  tick minor 500                       \n"
	  << "@    zeroxaxis  tick offsetx 0.000000                \n"
	  << "@    zeroxaxis  tick offsety 0.000000                \n"
	  << "@    zeroxaxis  label \"\"                             \n"
	  << "@    zeroxaxis  label layout para                    \n"
	  << "@    zeroxaxis  label place auto                     \n"
	  << "@    zeroxaxis  label char size 1.000000             \n"
	  << "@    zeroxaxis  label font 4                         \n"
	  << "@    zeroxaxis  label color 1                        \n"
	  << "@    zeroxaxis  label linewidth 1                    \n"
	  << "@    zeroxaxis  ticklabel off                        \n"
	  << "@    zeroxaxis  ticklabel type auto                  \n"
	  << "@    zeroxaxis  ticklabel prec 1                     \n"
	  << "@    zeroxaxis  ticklabel format decimal             \n"
	  << "@    zeroxaxis  ticklabel append \"\"                  \n"
	  << "@    zeroxaxis  ticklabel prepend \"\"                 \n"
	  << "@    zeroxaxis  ticklabel layout horizontal          \n"
	  << "@    zeroxaxis  ticklabel skip 0                     \n"
	  << "@    zeroxaxis  ticklabel stagger 0                  \n"
	  << "@    zeroxaxis  ticklabel op bottom                  \n"
	  << "@    zeroxaxis  ticklabel sign normal                \n"
	  << "@    zeroxaxis  ticklabel start type auto            \n"
	  << "@    zeroxaxis  ticklabel start 0.000000             \n"
	  << "@    zeroxaxis  ticklabel stop type auto             \n"
	  << "@    zeroxaxis  ticklabel stop 0.000000              \n"
	  << "@    zeroxaxis  ticklabel char size 1.000000         \n"
	  << "@    zeroxaxis  ticklabel font 4                     \n"
	  << "@    zeroxaxis  ticklabel color 1                    \n"
	  << "@    zeroxaxis  ticklabel linewidth 1                \n"
	  << "@    zeroxaxis  tick major off                       \n"
	  << "@    zeroxaxis  tick minor on                        \n"
	  << "@    zeroxaxis  tick default 6                       \n"
	  << "@    zeroxaxis  tick in                              \n"
	  << "@    zeroxaxis  tick major color 1                   \n"
	  << "@    zeroxaxis  tick major linewidth 1               \n"
	  << "@    zeroxaxis  tick major linestyle 1               \n"
	  << "@    zeroxaxis  tick minor color 1                   \n"
	  << "@    zeroxaxis  tick minor linewidth 1               \n"
	  << "@    zeroxaxis  tick minor linestyle 1               \n"
	  << "@    zeroxaxis  tick log off                         \n"
	  << "@    zeroxaxis  tick size 1.000000                   \n"
	  << "@    zeroxaxis  tick minor size 0.500000             \n"
	  << "@    zeroxaxis  bar off                              \n"
	  << "@    zeroxaxis  bar color 1                          \n"
	  << "@    zeroxaxis  bar linestyle 1                      \n"
	  << "@    zeroxaxis  bar linewidth 1                      \n"
	  << "@    zeroxaxis  tick major grid off                  \n"
	  << "@    zeroxaxis  tick minor grid off                  \n"
	  << "@    zeroxaxis  tick op both                         \n"
	  << "@    zeroxaxis  tick type auto                       \n"
	  << "@    zeroxaxis  tick spec 0                          \n"
	  << "@    zeroyaxis  tick on                              \n"
	  << "@    zeroyaxis  tick major 0.002                     \n"
	  << "@    zeroyaxis  tick minor 0.001                     \n"
	  << "@    zeroyaxis  tick offsetx 0.000000                \n"
	  << "@    zeroyaxis  tick offsety 0.000000                \n"
	  << "@    zeroyaxis  label \"\"                             \n"
	  << "@    zeroyaxis  label layout para                    \n"
	  << "@    zeroyaxis  label place auto                     \n"
	  << "@    zeroyaxis  label char size 1.000000             \n"
	  << "@    zeroyaxis  label font 4                         \n"
	  << "@    zeroyaxis  label color 1                        \n"
	  << "@    zeroyaxis  label linewidth 1                    \n"
	  << "@    zeroyaxis  ticklabel off                        \n"
	  << "@    zeroyaxis  ticklabel type auto                  \n"
	  << "@    zeroyaxis  ticklabel prec 3                     \n"
	  << "@    zeroyaxis  ticklabel format decimal             \n"
	  << "@    zeroyaxis  ticklabel append \"\"                  \n"
	  << "@    zeroyaxis  ticklabel prepend \"\"                 \n"
	  << "@    zeroyaxis  ticklabel layout horizontal          \n"
	  << "@    zeroyaxis  ticklabel skip 0                     \n"
	  << "@    zeroyaxis  ticklabel stagger 0                  \n"
	  << "@    zeroyaxis  ticklabel op left                    \n"
	  << "@    zeroyaxis  ticklabel sign normal                \n"
	  << "@    zeroyaxis  ticklabel start type auto            \n"
	  << "@    zeroyaxis  ticklabel start 0.000000             \n"
	  << "@    zeroyaxis  ticklabel stop type auto             \n"
	  << "@    zeroyaxis  ticklabel stop 0.000000              \n"
	  << "@    zeroyaxis  ticklabel char size 1.000000         \n"
	  << "@    zeroyaxis  ticklabel font 4                     \n"
	  << "@    zeroyaxis  ticklabel color 1                    \n"
	  << "@    zeroyaxis  ticklabel linewidth 1                \n"
	  << "@    zeroyaxis  tick major off                       \n"
	  << "@    zeroyaxis  tick minor on                        \n"
	  << "@    zeroyaxis  tick default 6                       \n"
	  << "@    zeroyaxis  tick in                              \n"
	  << "@    zeroyaxis  tick major color 1                   \n"
	  << "@    zeroyaxis  tick major linewidth 1               \n"
	  << "@    zeroyaxis  tick major linestyle 1               \n"
	  << "@    zeroyaxis  tick minor color 1                   \n"
	  << "@    zeroyaxis  tick minor linewidth 1               \n"
	  << "@    zeroyaxis  tick minor linestyle 1               \n"
	  << "@    zeroyaxis  tick log off                         \n"
	  << "@    zeroyaxis  tick size 1.000000                   \n"
	  << "@    zeroyaxis  tick minor size 0.500000             \n"
	  << "@    zeroyaxis  bar off                              \n"
	  << "@    zeroyaxis  bar color 1                          \n"
	  << "@    zeroyaxis  bar linestyle 1                      \n"
	  << "@    zeroyaxis  bar linewidth 1                      \n"
	  << "@    zeroyaxis  tick major grid off                  \n"
	  << "@    zeroyaxis  tick minor grid off                  \n"
	  << "@    zeroyaxis  tick op both                         \n"
	  << "@    zeroyaxis  tick type auto                       \n"
	  << "@    zeroyaxis  tick spec 0                          \n"
	  << "@    legend on                                       \n"
	  << "@    legend loctype view                             \n"
	  << "@    legend layout 0                                 \n"
	  << "@    legend vgap 2                                   \n"
	  << "@    legend hgap 1                                   \n"
	  << "@    legend length 4                                 \n"
	  << "@    legend box off                                  \n"
	  << "@    legend box fill off                             \n"
	  << "@    legend box fill with color                      \n"
	  << "@    legend box fill color 0                         \n"
	  << "@    legend box fill pattern 1                       \n"
	  << "@    legend box color 1                              \n"
	  << "@    legend box linewidth 1                          \n"
	  << "@    legend box linestyle 1                          \n"
	  << "@    legend x1 0.177989                              \n"
	  << "@    legend y1 0.418719                              \n"
	  << "@    legend font 5                                   \n"
	  << "@    legend char size 0.830000                       \n"
	  << "@    legend linestyle 1                              \n"
	  << "@    legend linewidth 1                              \n"
	  << "@    legend color 1                                  \n"
//	  << "@    legend string 0 \"with Std. Dev.:\"             \n"
//        << "@    legend string 1 \"with Mean:\"                  \n"
  	  << "@    legend string 0 \"with <y>= & \\8s\\5=\"           \n"
  	  << "@    legend string 1 \"with <y>= & \\8s\\5=\"           \n"
	  << "@    frame on                                        \n"
	  << "@    frame type 0                                    \n"
	  << "@    frame linestyle 1                               \n"
	  << "@    frame linewidth 2                               \n"
	  << "@    frame color 1                                   \n"
	  << "@    frame fill off                                  \n"
	  << "@    frame background color 0                        \n"
          ;

    /* *
     * SECTION FOR THE WRITING OF THE DATA
     * */
 
    // FIRST GRAPH, TOP
    int i;

    out_file << "@WITH G0\n";
    out_file << "@G0 ON\n";

    out_file << "@TYPE xy\n";
    // DISTANCE FROM ORIGIN VS LENGTH
    for (i=0; i<=dq.dist_r0_rn.last_one; i++)
    {
       out_file << "\t" << dq.accum_s[i] 
                << "\t" << dq.dist_r0_rn[i] << "\n";
    }
    out_file << "&\n";

    out_file << "@TYPE xy\n";
    // RADIUS OF GYRATION VS LENGTH
    for (i=0; i<=dq.RG.last_one; i++)
    {
       out_file << "\t" << dq.accum_s[i] 
                << "\t" << dq.RG[i] << "\n";
    }
    out_file << "&\n";

    // SECOND GRAPH, BOTTOM

    out_file << "@WITH G1\n";
    out_file << "@G1 ON\n";

    out_file << "@TYPE xy\n";
    // CURVATURE
    for (i=0; i<=dq.curv_3pt_1.last_one; i++)
    {
       // SKIP FIRST TWO POINTS
       if (i>1)
         out_file << "\t" << dq.accum_s[i] 
                  << "\t" << dq.curv_3pt_1[i] << "\n";
    }
    out_file << "&\n";

    out_file << "@TYPE xy\n";
    // ABSOLUTE VALUE OF THE CURVATURE
    for (i=0; i<=dq.curv_3pt_1.last_one; i++)
    {
       // SKIP FIRST TWO POINTS
       if (i>1)
         out_file << "\t" << dq.accum_s[i] 
                  << "\t" << ABS(dq.curv_3pt_1[i]) << "\n";
    }
    out_file << "&\n";
}

/*
======================================================================
*/
