
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#include <math.h>
#include <stdlib.h>
#include "curvature.h"
#include "macros.h"
#include "data.h"

float threept_curv_mth1(data &dq)
	// THREE-POINT CURVATURE CALCULATED FROM THE POSITION OF THE
        // INTERSECTION OF THE TWO PERPENDICULAR BISECTORS OF THE
        // TWO LINES JOINING THE THREE POINTS
{
     float curv = -1.;

     // NOT ENOUGH POINTS, HAVE TO HAVE AT LEAST 3.
     if ( dq.list_x.last_one < 2 )
        return -1.;

     // LABELS FOR THE LAST THREE POINTS
     int p3 = dq.list_x.last_one;
     int p2 = dq.list_x.last_one-1;
     int p1 = dq.list_x.last_one-2;

     // COORDINATES FOR THE LAST THREE POINTS
     float x1 = dq.list_x[p1];
     float y1 = dq.list_y[p1];
     float x2 = dq.list_x[p2];
     float y2 = dq.list_y[p2];
     float x3 = dq.list_x[p3];
     float y3 = dq.list_y[p3];

//   PRINT3("CURV: 1 ",x1,y1);
//   PRINT3("      2 ",x2,y2);
//   PRINT3("      2 ",x3,y3);

     // DIFFERENCES
     float d21x = x2 - x1;
     float d32x = x3 - x2;
     float d21y = y2 - y1;
     float d32y = y3 - y2;
     float d31y = y3 - y1;

     float crit = d21y * d32x - d21x * d32y;
//   PRINT2("       * CRIT  * ",crit);

     // RETURN IF NO CURVATURE
     if ( crit == 0. ) return 0.;

     // ADDITIONAL PARAMTERS
     float alpha1 = ( x1 + x2 ) / 2.;
     float alpha2 = ( x2 + x3 ) / 2.;
     float beta1  = ( y1 + y2 ) / 2.;
     float beta2  = ( y2 + y3 ) / 2.;
     
     // X COOR OF PERPEN BISECTOR
     float num_x = d32y*d21y*d31y/2. + alpha2*d21y*d32x - alpha1*d21x*d32y;
     float x     = num_x / crit;

     // Y COOR OF PERPEN BISECTOR
     float y;
     if ( d21y != 0. )
        y = d21x*(alpha1-x)/d21y + beta1;
     else
        y = d32x*(alpha2-x)/d32y + beta2;
    
//   PRINT3("       * COORs * ",x,y);

     // CURVATURE
     float dist_x = (x-x1);
     float dist_y = (y-y1);
     curv = 1. / sqrt( dist_x*dist_x + dist_y*dist_y );
//   PRINT2("       * CURV  * ",curv);

     // SIGN OF CURVATURE
     curv = SIGN(crit) * curv;

     return curv;
}

float threept_curv_mth2(data &dq)
	// THREE-POINT CURVATURE CALCULATED FROM THE DIFFERENCE
        // BETWEEN THE TWO ANGLES SUBTENDED BY THE 
        // TWO LINES JOINING THE THREE POINTS
{
     float curv = -1.;

     // NOT ENOUGH POINTS, HAVE TO HAVE AT LEAST 3.
     if ( dq.list_x.last_one < 2 )
        return -1.;

     // LABELS FOR THE LAST THREE POINTS
     int p3 = dq.list_x.last_one;
     int p2 = dq.list_x.last_one-1;
     int p1 = dq.list_x.last_one-2;

     // COORDINATES FOR THE LAST THREE POINTS
     float x1 = dq.list_x[p1];
     float y1 = dq.list_y[p1];
     float x2 = dq.list_x[p2];
     float y2 = dq.list_y[p2];
     float x3 = dq.list_x[p3];
     float y3 = dq.list_y[p3];

//   PRINT3("CURV: 1 ",x1,y1);
//   PRINT3("      2 ",x2,y2);
//   PRINT3("      2 ",x3,y3);

     // DIFFERENCES
     float d21x = x2 - x1;
     float d32x = x3 - x2;
     float d21y = y2 - y1;
     float d32y = y3 - y2;
     
     // FIRST ANGLE
     float alpha1;
     if      ( ( d21x == 0. ) && ( d21y > 0. ) ) 
	alpha1 = PI_2;
     else if ( ( d21x == 0. ) && ( d21y < 0. ) ) 
        alpha1 = -PI_2;
     else if ( ( d21x == 0. ) && ( d21y == 0. ) ) 
        return -1.;
     else
     {
        alpha1 = atan(d21y/d21x);
     }
     
     // SECOND ANGLE
     float alpha2;
     if      ( ( d32x == 0. ) && ( d32y > 0. ) ) 
	alpha2 = PI_2;
     else if ( ( d32x == 0. ) && ( d32y < 0. ) ) 
        alpha2 = -PI_2;
     else if ( ( d32x == 0. ) && ( d32y == 0. ) ) 
        return -1.;
     else
     {
        alpha2 = atan(d32y/d32x);
     }

     // DISTANCES
     float s1 = sqrt( d21x*d21x + d21y*d21y );
     float s2 = sqrt( d32x*d32x + d32y*d32y );

     // CURVATURE
     curv = 2. * (alpha2 - alpha1) / (s1 + s2);

     return curv;
}
