
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#include <stdlib.h>
#include "data.h"

data::data(void)
{
    /* *
     * SIZES OF THE CANVAS AND COORDINATE SYSTEM
     * */
    size_canvas_x = size_canvas_y  = 1024;
//  size_canvas_x = size_canvas_y = 512;

    ortho_x = ortho_y = 1024.;
    ortho_z = 20.;

    // PARAMETERS FOR THE VISUAL THRESHOLDING
#ifdef ALPHA4
    beta = 4.;
//  beta = 10.;
//  beta = 15.;
    mu   = .5;
#endif
#ifdef ONYX
    beta = 1.;
    mu   = .5;
#endif

    int i;
    for (i=0; i<3; i++) displayList[i]=-1;
    for (i=0; i<3; i++) switchReadSlice[i]=0;

    switch_redraw_canvasrun = 1;

    switch_init_data_collect         = 0;
    switch_first_point_data_collect  = 1;
    // REAL PICTURE POSITIONS
    x0_p = y0_p = x1_p = y1_p = 0.;
    // CANVAS POSITIONS
    x0_canv = y0_canv = x1_canv = y1_canv = 0.;
    // TOTAL DISPLACEMENT
    total_s = 0.;

    sweep_ch = new int[3];
    sweep_ch[0] = 2;
    sweep_ch[1] = 1;
    sweep_ch[2] = 3;

    list_x.reset();
    list_y.reset();
    list_x_all.reset();
    list_y_all.reset();
    accum_s.reset();
    curv_3pt_1.reset();
    curv_3pt_2.reset();
    dist_r0_rn.reset();

    accum_pos_x    = 0.;
    accum_pos_y    = 0.;
    accum_pos_xsqr = 0.;
    accum_pos_ysqr = 0.;
    RG.reset();

    // SWITCHES MODE, 
    // 1 - CURVATURE MODE
    // 2 - WIDTH MODE
    switch_mode_curv_width = 1;
    switch_is_first_width_point = 1;
    switch_is_second_width_done = 0;
    list_x_w.reset();
    list_y_w.reset();
    list_x_w_all.reset();
    list_y_w_all.reset();
    accum_s_w.reset();
}

data::~data(void)
{
    delete [] sweep_ch;
}

void data::ClearLists(void)
{
	 list_x.clear();    
	 list_y.clear();
	 list_x_w.clear();    
	 list_y_w.clear();
         // NOT CLEAN THESE, THEY CONTAIN ALL OF THE CLICKS
//	 list_x_all.clear();    
//	 list_y_all.clear();
//	 list_x_w_all.clear();    
//	 list_y_w_all.clear();
	 accum_s.clear();   
	 curv_3pt_1.clear();   
	 curv_3pt_2.clear();   
	 dist_r0_rn.clear();   
	 RG.clear();   
         accum_s_w.clear();
}

void data::Clear(void)
{
    int i;
    for (i=0; i<3; i++) displayList[i]=-1;
    for (i=0; i<3; i++) switchReadSlice[i]=0;

    switch_redraw_canvasrun = 1;

    switch_init_data_collect         = 0;
    switch_first_point_data_collect  = 1;
    // REAL PICTURE POSITIONS
    x0_p = y0_p = x1_p = y1_p = 0.;
    // CANVAS POSITIONS
    x0_canv = y0_canv = x1_canv = y1_canv = 0.;
    // TOTAL DISPLACEMENT
    total_s = 0.;

    list_x.reset();
    list_y.reset();
    list_x_w.reset();
    list_y_w.reset();
    list_x_all.reset();
    list_y_all.reset();
    list_x_w_all.reset();
    list_y_w_all.reset();
    accum_s.reset();
    curv_3pt_1.reset();
    curv_3pt_2.reset();
    dist_r0_rn.reset();

    accum_pos_x    = 0.;
    accum_pos_y    = 0.;
    accum_pos_xsqr = 0.;
    accum_pos_ysqr = 0.;
    RG.reset();

    x0_w = y0_w = 0.;
    x1_w = y1_w = 0.;
    x0_mid_w = y0_mid_w = 0.;
    x1_mid_w = y1_mid_w = 0.;
    switch_is_first_width_point = 1;
    switch_is_second_width_done = 0;
    accum_s_w.reset();
}

void data::CopyTempCoorToPermCoor(void)
{
     // COPIES THE CURRENT TRACE DATA POINTS
     // TO THE PERMANENT LIST OF POINTS
     for (int i=0; i<=list_x.last_one; i++)
     {
         list_x_all.add_one( list_x[i] );
         list_y_all.add_one( list_y[i] );
     }
}

void data::CopyTempCoorToPermCoorWidths(void)
{
     // COPIES THE CURRENT TRACE DATA POINTS
     // TO THE PERMANENT LIST OF POINTS OF THE WIDTHS
     for (int i=0; i<=list_x_w.last_one; i++)
     {
         list_x_w_all.add_one( list_x_w[i] );
         list_y_w_all.add_one( list_y_w[i] );
     }
}

/*
======================================================================
*/

