
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#ifndef DATA_H
#define DATA_H

#include "templates/number.h"
#include "templates/infobjarray.h"

class data
{
public:
    data(void);
    ~data(void);
private:        
    data(const data &z);
    data &operator=(const data &z);
public:
    void Clear(void);

    int size_canvas_x;
    int size_canvas_y;

    float ortho_x;
    float ortho_y;
    float ortho_z;

    // FOR THE COLOR-RAMP
    float beta, mu;

    int displayList[3];
    int switchReadSlice[3];

    int switch_redraw_canvasrun;
    
    int switch_init_data_collect;
    int switch_first_point_data_collect;
    float x0_p, y0_p;
    float x1_p, y1_p;
    float x0_canv, y0_canv;
    float x1_canv, y1_canv;
    float total_s;

    // DRAWING SWEEPS FOR EACH CHANNEL
    int *sweep_ch;

    // CLEAR ALL LISTS
    void ClearLists(void);

    // COPIES THE CURRENT TRACE DATA POINTS
    // TO THE PERMANENT LIST OF POINTS
    void CopyTempCoorToPermCoor(void);

    // ARRAY OF POINTS CHOSEN FROM CLICKING
    infobjarray<number<float>,20> list_x;
    infobjarray<number<float>,20> list_y;
    infobjarray<number<float>,20> list_x_all;
    infobjarray<number<float>,20> list_y_all;
    infobjarray<number<float>,20> accum_s;
    infobjarray<number<float>,20> dist_r0_rn;

    // ARRAYS OF STATISTICS.
    // ACCUMULATE THE SUM OF THE POSITIONS AND
    // POSITIONS SQUARED.
    // RG = RADIUS OF GYRATION.
    float accum_pos_x;
    float accum_pos_y;
    float accum_pos_xsqr;
    float accum_pos_ysqr;
    infobjarray<number<float>,20> RG;

    // ARRAYS OF CURVATURES
    infobjarray<number<float>,20> curv_3pt_1;
    infobjarray<number<float>,20> curv_3pt_2;

    // SWITCHES MODE, 
    // 1 - CURVATURE MODE
    // 2 - WIDTH MODE
    int switch_mode_curv_width;
    int switch_is_first_width_point;
    int switch_is_second_width_done;

    // STORED ARRAY OF POINTS COMING FROM THE WIDTHS
    infobjarray<number<float>,20> list_x_w;
    infobjarray<number<float>,20> list_y_w;
    infobjarray<number<float>,20> list_x_w_all;
    infobjarray<number<float>,20> list_y_w_all;

    // CURRENT TWO POINTS CLICKED FOR THE WIDTH CALCULATION
    float x0_w, y0_w;
    float x1_w, y1_w;
    float x0_mid_w, y0_mid_w;
    float x1_mid_w, y1_mid_w;
    // ACCUMULATED DISTANCE FOR THE WIDTHS
    infobjarray<number<float>,20> accum_s_w;

    // COPIES THE CURRENT TRACE DATA POINTS
    // TO THE PERMANENT LIST OF POINTS FOR THE WIDTHS
    void CopyTempCoorToPermCoorWidths(void);
};

#endif // DATA_H
