
/*
 * Luis Cruz
 * Center for Polymer Studies
 * Boston University
 * August, 1997
 * ccruz@bu.edu
 *
 */

#include "picfunc.h"
#include "lattice.h"
#include "macros.h"


long slices_PIC(char* b, long& size_x, long& size_y)
	// RETURNS THE NUMBER OF SLICES AND THE SIZE OF A PIC FILE
	// GIVEN THE FIRST 76 BYTES.
{
	// TO EXTRACT THE SIZE OF THE PICTURE FROM THE FIRST 76 BYTES.
	size_x = long(b[0]) | long(b[1]<<8);
	size_y = long(b[2]) | long(b[3]<<8);

	long no_slices = long(b[4]) | long(b[5]<<8);

	cout << "Size (" << size_x << ", " << size_y << ")\n" << flush;
	cout << no_slices << " slices.\n" << flush;

	return no_slices;
}

int read_reduced_PIC_slice(ifstream& in_file, int size_pic_x, int size_pic_y,
		           int no, lattice& z)
	// READS A PIC COMPOSED OF A SLICES. 
	// PUTS IN CANVAS AT SPECIFIED POINT.
{
	int tot_size_bytes = size_pic_x * size_pic_y;

	char *b = NULL;

	int levels = 255;
	int a;

	int i, j;
	int element;

	b = new char[tot_size_bytes+1];

	int max_slices = 1;

	in_file.read(b,tot_size_bytes);

	cout << "Read slice " << max_slices << "\n" << flush;

	while ( max_slices < no )
	{
	     in_file.read(b,tot_size_bytes);

	     max_slices++;
	     cout << "Read slice " << max_slices << "\n" << flush;

	     if ( in_file.gcount() < (tot_size_bytes) )
	     {
		 cout << "Incomplete slide read.\n" << flush;
		 return 0;
	     }         
	}

	// GO THROUGH ALL OF THE PIXELS
	for (i = 0; i<size_pic_y; i++) 
	{
	  for (j = 0; j<size_pic_x; j++) 
	  {
	     int temp_a = 0;

	     element = size_pic_x * i + j; 
	
	     // FIRST PIXEL
	     if ( int(b[element])<0 ) 
	       a = - int(b[element]);
	     else 
	       a = levels - int(b[element]);

	     temp_a += (levels - a);

	     // CONVERT TO LATTICE POSITION, UPPER RIGHT
	     z(j,i)      = float(temp_a)/float(levels);
	  }   
	}
	delete [] b;
	return 1;
}

int read_reduced_PIC_no_slices(ifstream& in_file, 
	        int size_pic_x, int size_pic_y, int no, lattice** z)
	// READS A PIC COMPOSED OF no SLICES. 
{
	int tot_size_bytes = size_pic_x * size_pic_y;
	int a,i,j,element,levels = 255;
	int max_slices = 0;
        lattice *temp_lat;

	char *b = new char[tot_size_bytes+1];

	in_file.read(b,tot_size_bytes);

	do
	{
            // RESIZE THE LATTICES
            (z[max_slices])->resize(1024,1024);

	    if ( in_file.gcount() < (tot_size_bytes) )
	    {
		cout << "Incomplete slide read.\n" << flush;
		return 0;
	    }         

	    // GO THROUGH ALL OF THE PIXELS
	    for (i = 0; i<size_pic_y; i++) 
	    {
	      for (j = 0; j<size_pic_x; j++) 
	      {
		 int temp_a = 0;

		 element = size_pic_x * i + j; 
	
		 // FIRST PIXEL
		 if ( int(b[element])<0 ) 
		   a = - int(b[element]);
		 else 
		   a = levels - int(b[element]);

		 temp_a += (levels - a);

		 // CONVERT TO LATTICE POSITION, UPPER RIGHT
                 temp_lat = z[max_slices];
		 (*temp_lat)(j,i) = float(temp_a)/float(levels);
	      }   
	    }   

	    in_file.read(b,tot_size_bytes);

	    max_slices++;
	    cout << "Read slice " << max_slices << "\n" << flush;

	} while ( max_slices < no );

	delete [] b;
	return 1;
}

/*
======================================================================
*/
